package PAR::StrippedPARL::Dynamic;
use 5.008001;
use strict;
use warnings;
our $VERSION = '0.958';

use base 'PAR::StrippedPARL::Base';

our $Data_Pos = tell DATA;

=head1 NAME

PAR::StrippedPARL::Dynamic - Data package containing a dynamic PARL

=head1 SYNOPSIS

  # For details, see PAR::StrippedPARL::Base.
  PAR::StrippedPARL::Dynamic->write_parl($file) or die "Some error...";

=head1 DESCRIPTION

This class is internal to PAR. Do not use it outside of PAR.

This class is basically just a container for a dynamic binary PAR loader
which doesn't include the PAR code like the F<parl> or F<parl.exe>
you are used to. If you're really curious, I'll tell you it is
just a copy of the F<myldr/par> (or F<myldr/par.exe>) file.

The data is appended during the C<make> phase of the PAR build process,
but only if applicable: If you perl is static, you won't get the dynamic
loader.

If the binary data isn't appended during the build process, the class
methods will return the empty list.

=head1 CLASS METHODS

Inherits the methods from L<PAR::StrippedPARL::Base>.

=cut

sub _data_pos {
    my $class = shift;
    return $Data_Pos;
}

=head1 AUTHORS

Steffen Mueller E<lt>smueller@cpan.orgE<gt>,
Audrey Tang E<lt>cpan@audreyt.orgE<gt>

=head1 COPYRIGHT AND LICENSE

Copyright 2006-2009 by Steffen Mueller E<lt>smueller@cpan.orgE<gt>.

This program is free software; you can redistribute it and/or 
modify it under the same terms as Perl itself.

See F<LICENSE>.

=cut

$^V eq 5.28.2 
    or die sprintf("Perl (%s) version (%vd) doesn't match the version (5.28.2) ".
                   "that PAR::Packer was built with; please rebuild PAR::Packer", 
                   $^X, $^V);

1;

__DATA__
M?T5,1@(!`0````````````,`%0`!````%",```````!``````````#@!`0``
M`````@```$``.``(`$``%@`5``8````$````0`````````!``````````$``
M````````P`$```````#``0````````@``````````P````0``````@``````
M```"``````````(````````>`````````!X``````````0`````````!````
M!0```````````````````````````````````"R?````````+)\`````````
M``$```````$````&````*/L````````H^P$``````"C[`0``````4`4`````
M``"X%0```````````0```````@````8```!(^P```````$C[`0``````2/L!
M``````#``0```````,`!````````"`````````!0Y71D!````*"9````````
MH)D```````"@F0```````-P`````````W``````````$`````````%'E=&0&
M`````````````````````````````````````````````````````````!``
M````````4N5T9`0````H^P```````"C[`0``````*/L!``````#8!```````
M`-@$`````````0`````````O;&EB+VQD+6UU<VPM<&]W97)P8S8T;&4N<V\N
M,0```!$```!,````!`````@````@$!``!4`$@"@`$`2`A@"$@B$```D`!`F(
M@!A!N@0""`````!,````4````%0```!5````6P```%P```!=`````````%\`
M``!@`````````&$```!B````9```````````````:G^:?.K3[P[.WD<M;\7?
M'R[%F[:XC?$.U&34?"'_Y`[9<5@<^J%L8,+E/RRR`8MO0OK7A^)'Q@&[XY)\
M5<,\TF>OS&:(!W#30T75[#-BV^T5C"7,?ZF<F^"G`@IK&IY0H^#[20``````
M```````````````````````````````#``<`N!@`````````````````````
M```#``T`*/L!``````````````````P````28```````````````````````
M`+\!```28````````````````````````!0````1````````````````````
M`````.4!```1`````````````````````````&$!```28```````````````
M`````````!L````28````````````````````````)X!```28```````````
M`````````````",````28````````````````````````/(!```28```````
M`````````````````*H!```28````````````````````````"H````@````
M`````````````````````"8#```A`````````````````````````$(````2
M8````````````````````````$@````2`````````````````````````$\`
M```2`````````````````````````/,"```28```````````````````````
M`.0"```28````````````````````````'<"```28```````````````````
M`````%8````2`````````````````````````!@"```28```````````````
M`````````%T````28````````````````````````*P"```28```````````
M`````````````&0````28````````````````````````&P````2````````
M`````````````````)4"```28````````````````````````'0````28```
M`````````````````````'H````28````````````````````````(,````@
M`````````````````````````-T"```28````````````````````````)\`
M```28````````````````````````*0````28```````````````````````
M``,"```1`````````````````````````+,"```28```````````````````
M`````$4"```28````````````````````````*L````28```````````````
M`````````#<"```28````````````````````````$H#```28```````````
M`````````````"4#```1`````````````````````````&D"```28```````
M`````````````````!(#```28````````````````````````"<#```1````
M`````````````````````+(````28`````````````````````````H#```2
M8````````````````````````&\!```28````````````````````````+L`
M```B`````````````````````````,H````@````````````````````````
M`.`````28````````````````````````-4"```28```````````````````
M`````%4"```28````````````````````````.4````28```````````````
M`````````.L````@`````````````````````````*`"```28```````````
M``````````````4!```28````````````````````````(\!```28```````
M``````````````````H!```28````````````````````````(4"```28```
M`````````````````````'X!```28````````````````````````!`!```2
M`````````````````````````"$!```28````````````````````````!,"
M```28````````````````````````'4````28```````````````````````
M`"0"```28````````````````````````%X"```28```````````````````
M``````,#```28````````````````````````"<!```2````````````````
M`````````/L"```28````````````````````````#L!```2````````````
M``````````````X"```28````````````````````````,T!```28```````
M`````````````````$(!```2`````````````````````````$D!```2````
M`````````````````````"0#```A`````````````````````````%H!```2
M`````````````````````````!\#```28`@`H"````````!T`@```````-\!
M```28`D`+%P````````0`````````(P#```28`@`N#0````````@!P``````
M`#@$```28`@`P#\```````"8`````````&D#```28`@`F"T````````8````
M`````/8#```28`<`N!@````````0`````````*\#```28`@`V#L```````#H
M`P```````!P$```28`@`L"T````````0`@```````.<#```0`!,`>``"````
M`````````````'H#```28`@`]#,```````#$`````````)D#```28`@`Y"L`
M``````!D`````````*$#```28`@`'#,```````",`````````,4#```28`@`
M&%<```````!``0```````-H#```2``@`P"\````````X`````````#,$```0
M`!,`X!`"`````````````````"\#```28`@`0",```````!,`````````/P#
M```28`@`^"\```````!@`0```````-`#```1`!(`<``"```````(````````
M`!4$```0`!(`>``"`````````````````.P#```2``@`%",`````````````
M`````/,#```28`@`A%8```````"4`````````#@#```28`@`J#,```````!,
M`````````%,#```28`@`P"P```````#8`````````"D$```28`@`6%@`````
M``"D`0````````@$```28`@`6#$```````#$`0````````!L:6)P97)L+G-O
M`&]P96YD:7(`<W1D97)R`')E86QL;V,`86-C97-S`%]?9&5R96=I<W1E<E]F
M<F%M95]I;F9O`&QS965K`&=E='!I9`!S=')C;7``;65M<V5T`'5N;&EN:P!M
M96UM;W9E`'-T<FYC;7``;'-T870`8VQO<V5D:7(`7TE435]D97)E9VES=&5R
M5$U#;&]N951A8FQE`&]P96X`<W1R<W1R`'-T<F-H<@!R96%D;&EN:P!?7V-X
M85]F:6YA;&EZ90!?7W)E9VES=&5R7V9R86UE7VEN9F\`97AI=`!C;&]S90!?
M251-7W)E9VES=&5R5$U#;&]N951A8FQE`')E860`<FUD:7(`7U]E<G)N;U]L
M;V-A=&EO;@!M:V1I<@!P=&AR96%D7V=E='-P96-I9FEC`&UE;6-P>0!S=')L
M96X`7U]S=&%C:U]C:&M?9F%I;`!G971U:60`4&5R;%]S>7-?=&5R;0!097)L
M7W-Y<U]I;FET,P!097)L7V%T9F]R:U]L;V-K`'!E<FQ?8V]N<W1R=6-T`%!E
M<FQ?9V5T7W-V`%!E<FQ?8W)O86M?;F]C;VYT97AT`%!E<FQ?879?<VAI9G0`
M4&5R;%]S=E\R<'9?9FQA9W,`7V9I;FD`4$Q?9&]?=6YD=6UP`%!E<FQ?;F5W
M6%-?9FQA9W,`4$Q?=&AR7VME>0!P97)L7V9R964`4&5R;%]M9U]S970`4&5R
M;%]A=&9O<FM?=6YL;V-K`%!E<FQ?<W9?<V5T<'8`4&5R;%]G=E]F971C:'!V
M`'!E<FQ?<G5N`%!E<FQ?;F5W6%,`<&5R;%]D97-T<G5C=`!097)L7V%V7V9E
M=&-H`&)O;W1?1'EN84QO861E<@!P97)L7W!A<G-E`%!E<FQ?<V%F97-Y<VUA
M;&QO8P!P97)L7V%L;&]C`&QI8F,N;75S;"UP<&,V-&QE+G-O+C$`9G!R:6YT
M9@!S=')D=7``<'1H<F5A9%]A=&9O<FL`<F5A9&1I<@!S<')I;G1F`'-T<G1O
M:P!S=')N8W!Y`%]?;&EB8U]S=&%R=%]M86EN`%]?7V5N=FER;VX`7W-T87)T
M7V,`9V5T7W5S97)N86UE7V9R;VU?9V5T<'=U:60`<&%R7V-U<G)E;G1?97AE
M8U]P<F]C`'!A<E]C=7)R96YT7V5X96,`<&%R7W-E='5P7VQI8G!A=&@`<&%R
M7VUK=&UP9&ER`'AS7VEN:70`<&%R7V5N=E]C;&5A;@!84U]);G1E<FYA;'-?
M4$%27T)/3U0`<VAA7W5P9&%T90!M>5]P87)?<&P`<&%R7V)A<V5N86UE`%]?
M8G-S7W-T87)T`'-H85]I;FET`'!A<E]D:7)N86UE`'!A<E]I;FET7V5N=@!?
M961A=&$`<&%R7V9I;F1P<F]G`'-H85]F:6YA;`!?96YD`'!A<E]C;&5A;G5P
M`"]U<W(O;&EB+W!E<FPU+V-O<F5?<&5R;"]#3U)%`````````````@``````
M%@````````````(``````!```@``````%@`````````Z7P```````!@``@``
M````%@````````"%7````````"@``@``````%@````````!F70```````#``
M`@``````%@````````!?70```````#@``@``````%@`````````N7P``````
M`$```@``````%@````````!\70```````$@``@``````%@`````````V7P``
M`````%@``@``````%@`````````@7P```````&```@``````%@`````````E
M7P```````'```@``````%@`````````_7P````````C_`0``````)@```!X`
M`````````````!#_`0``````)@```#4``````````````!C_`0``````)@``
M`"\``````````````"#_`0``````)@````T``````````````"C_`0``````
M)@```#```````````````##_`0``````)@```"L``````````````#C_`0``
M````)@```"(``````````````$#_`0``````)@```#H``````````````$C_
M`0``````)@````4``````````````%#_`0``````)@```$``````````````
M`%C_`0``````)@```#L``````````````&#_`0``````)@````8`````````
M`````!C]`0``````%0````,``````````````"#]`0``````%0````0`````
M`````````"C]`0``````%0````<``````````````##]`0``````%0````@`
M`````````````#C]`0``````%0````D``````````````$#]`0``````%0``
M``H``````````````$C]`0``````%0````L``````````````%#]`0``````
M%0````P``````````````%C]`0``````%0````T``````````````&#]`0``
M````%0````\``````````````&C]`0``````%0```!```````````````'#]
M`0``````%0```!$``````````````'C]`0``````%0```!(`````````````
M`(#]`0``````%0```!,``````````````(C]`0``````%0```!0`````````
M`````)#]`0``````%0```!4``````````````)C]`0``````%0```!8`````
M`````````*#]`0``````%0```!<``````````````*C]`0``````%0```!@`
M`````````````+#]`0``````%0```!D``````````````+C]`0``````%0``
M`!H``````````````,#]`0``````%0```!L``````````````,C]`0``````
M%0```!P``````````````-#]`0``````%0```!T``````````````-C]`0``
M````%0```!\``````````````.#]`0``````%0```"```````````````.C]
M`0``````%0```"$``````````````/#]`0``````%0```",`````````````
M`/C]`0``````%0```"0```````````````#^`0``````%0```"4`````````
M``````C^`0``````%0```"8``````````````!#^`0``````%0```"<`````
M`````````!C^`0``````%0```"D``````````````"#^`0``````%0```"H`
M`````````````"C^`0``````%0```"P``````````````##^`0``````%0``
M`"T``````````````#C^`0``````%0```"X``````````````$#^`0``````
M%0```"\``````````````$C^`0``````%0```#```````````````%#^`0``
M````%0```#$``````````````%C^`0``````%0```#(``````````````&#^
M`0``````%0```#,``````````````&C^`0``````%0```#0`````````````
M`'#^`0``````%0```#8``````````````'C^`0``````%0```#<`````````
M`````(#^`0``````%0```#@``````````````(C^`0``````%0```#D`````
M`````````)#^`0``````%0```#P``````````````)C^`0``````%0```#T`
M`````````````*#^`0``````%0```#X``````````````*C^`0``````%0``
M`#\``````````````+#^`0``````%0```$$``````````````+C^`0``````
M%0```$(``````````````,#^`0``````%0```$,``````````````,C^`0``
M````%0```$0``````````````-#^`0``````%0```$4``````````````-C^
M`0``````%0```$8``````````````.#^`0``````%0```$<`````````````
M`.C^`0``````%0```$@``````````````/#^`0``````%0```$D`````````
M`````/C^`0``````%0```$L```````````````(`3#Q(9D(XI@((?!```?CA
M_R'XK0P`2````&`U00!(````8"``(3@0``'HI@,(?"``@$X`````````````
M`````````````!@`0?C__X(]>'Z,Z:8#B7T@!(!.````````````````&`!!
M^/__@CU8?XSII@.)?2`$@$X````````````````8`$'X__^"/=!_C.FF`XE]
M(`2`3@```````````````!@`0?C__X(]>'^,Z:8#B7T@!(!.````````````
M````&`!!^/__@CT(?XSII@.)?2`$@$X````````````````8`$'X__^"/3!^
MC.FF`XE](`2`3@```````````````!@`0?C__X(]*'Z,Z:8#B7T@!(!.````
M````````````&`!!^/__@CU`?HSII@.)?2`$@$X````````````````8`$'X
M__^"/:!_C.FF`XE](`2`3@```````````````!@`0?C__X(]N'Z,Z:8#B7T@
M!(!.````````````````&`!!^/__@CUP?XSII@.)?2`$@$X`````````````
M```8`$'X__^"/0!_C.FF`XE](`2`3@```````````````!@`0?C__X(]:'Z,
MZ:8#B7T@!(!.````````````````&`!!^/__@CV8?HSII@.)?2`$@$X`````
M```````````8`$'X__^"/6A_C.FF`XE](`2`3@```````````````!@`0?C_
M_X(]2'Z,Z:8#B7T@!(!.````````````````&`!!^/__@CWX?HSII@.)?2`$
M@$X````````````````8`$'X__^"/:A_C.FF`XE](`2`3@``````````````
M`!@`0?C__X(].'Z,Z:8#B7T@!(!.````````````````&`!!^/__@CU0?HSI
MI@.)?2`$@$X````````````````8`$'X__^"/4A_C.FF`XE](`2`3@``````
M`````````!@`0?C__X(]Z'^,Z:8#B7T@!(!.````````````````&`!!^/__
M@CW@?HSII@.)?2`$@$X````````````````8`$'X__^"/>A^C.FF`XE](`2`
M3@```````````````!@`0?C__X(]$'^,Z:8#B7T@!(!.````````````````
M&`!!^/__@CT8?XSII@.)?2`$@$X````````````````8`$'X__^"/=!^C.FF
M`XE](`2`3@```````````````!@`0?C__X(]D'^,Z:8#B7T@!(!.````````
M````````&`!!^/__@CW8?HSII@.)?2`$@$X````````````````8`$'X__^"
M/9!^C.FF`XE](`2`3@```````````````!@`0?C__X(]R'Z,Z:8#B7T@!(!.
M````````````````&`!!^/__@CW(?XSII@.)?2`$@$X````````````````8
M`$'X__^"/8!_C.FF`XE](`2`3@```````````````!@`0?C__X(]('Z,Z:8#
MB7T@!(!.````````````````&`!!^/__@CW`?XSII@.)?2`$@$X`````````
M```````8`$'X__^"/?!^C.FF`XE](`2`3@```````````````!@`0?C__X(]
M*'^,Z:8#B7T@!(!.````````````````&`!!^/__@CWP?XSII@.)?2`$@$X`
M```````````````8`$'X__^"/4!_C.FF`XE](`2`3@```````````````!@`
M0?C__X(]('^,Z:8#B7T@!(!.````````````````&`!!^/__@CTP?XSII@.)
M?2`$@$X````````````````8`$'X__^"/8!^C.FF`XE](`2`3@``````````
M`````!@`0?C__X(]^'^,Z:8#B7T@!(!.````````````````&`!!^/__@CV(
M?XSII@.)?2`$@$X````````````````8`$'X__^"/3A_C.FF`XE](`2`3@``
M`````````````!@`0?C__X(]B'Z,Z:8#B7T@!(!.````````````````&`!!
M^/__@CW@?XSII@.)?2`$@$X````````````````8`$'X__^"/;A_C.FF`XE]
M(`2`3@```````````````!@`0?C__X(]V'^,Z:8#B7T@!(!.````````````
M````&`!!^/__@CVH?HSII@.)?2`$@$X````````````````8`$'X__^"/5A^
MC.FF`XE](`2`3@```````````````!@`0?C__X(]&'Z,Z:8#B7T@!(!.````
M````````````&`!!^/__@CV@?HSII@.)?2`$@$X````````````````8`$'X
M__^"/;!_C.FF`XE](`2`3@```````````````!@`0?C__X(]P'Z,Z:8#B7T@
M!(!.````````````````&`!!^/__@CV8?XSII@.)?2`$@$X`````````````
M```8`$'X__^"/6!_C.FF`XE](`2`3@```````````````!@`0?C__X(]4'^,
MZ:8#B7T@!(!.````````````````&`!!^/__@CU@?HSII@.)?2`$@$X`````
M```````````8`$'X__^"/;!^C.FF`XE](`2`3@```````````````!@`0?C_
M_X(]<'Z,Z:8#B7T@!(!.`````````````````@!,/&!>0CBF`@A\\/_!^_C_
MX?L0``'X<?\A^'``@?AH`*'X<`"!.&@`H3A\`&&0?`!A.*W]_TL8`$'H````
M8%"`HN@```!@6(!BZ'@KI'PQ_?]+&`!!Z````&!@@"+I````8#B`XNL``,F+
M``">+T``GD!-_/]+&`!!Z````&```*,OV)%B^!``GD`!`&`X\?[_2Q@`0>C)
M^_]+&`!!Z```?X#]^_]+&`!!Z*$+PYL``'^`[?O_2Q@`0>@*!B.)`@`I80H&
M(YD``'^`U?O_2Q@`0>@*!B.)`0`I80H&(YE\`&&`!0!C.+0'8WPD'V-XL?C_
M2Q@`0>A^`*'H<`#AZ````&````!@````.<B18OAX&V9\```GZ0``A2\``"/Y
M_O\B/1K@*3D(`"/Y````8'"!(ND0`"/Y_O\B/1W@*3D8`"/Y!``@.<"1(I'_
M_R4Y(``I>0$`*3D(`)U!`0`@.0$`*2P!``@Y__\I.=P`@D`$`"4Y``!`.0``
M`&#8D6+HM`<I?0,`I3@D'REY_O^"/!1*)GT``.`XM`>E?$BMA#CX_TGY??W_
M2Q@`0>AY&W]\&`""0````&#8D6+HI?W_2Q@`0>AX&W]\````8-B18NBQ^?]+
M&`!!Z/[_8CP9WF,X'00`2```HR\\`)Y`````8-"1(ND``*DO&`">0/[_8CS.
MW6,X^0,`2````&#0D6+X````8-"18N@``*,O"`">00D=`$@```!@V)%BZ#7\
M_TL8`$'H[?;_2Q@`0>B0`"$X>/OC?P`X`$@D'PIY*E"'?`0`2#FT!TI])!]*
M>1121GWX_XKX_/[_2P`````````!@`(```(`3#SL6T(X*`",@!1BA'QX"R-\
MY`8A>````#CA_P'XI@,(?!$``$@TV`$``@!,/,!;0CBF`@A\"`"C./[_XCPL
MW><X_O_"/+B9QC@````Y$``!^.'_(?@"`(/H_O]B/*"A8SAI^O]+&`!!Z```
M```````!@````````&`"`$P\<%M".````&````!@>(%B.'B!(CD`&*E_(`">
M30```&`(@"+I``"I+R``GDVF`@A\>$LL?:8#*7T0``'XX?\A^!@`0?@A!(!.
M&`!!Z"``(3@0``'HI@,(?"``@$X"`$P\$%M".````&````!@>(%B.'B!@CA0
M((-\=!Z$?'0.A'R5`81\(`""30```&`0@"+I``"I+R``GDVF`@A\>$LL?:8#
M*7T0``'XX?\A^!@`0?@A!(!.&`!!Z"``(3@0``'HI@,(?"``@$X``$)@`@!,
M/*!:0C@```!@>($BB0``B2\@`)Y,I@((?````&`8@"+IZ/^A^_#_P?L``*DO
M$``!^,'_(?@8`$'X%`">00```&``@6+H&?G_2Q@`0>C__T(]___"/P```&"`
M@2+I0'Q*.3A\WCM04-Y___^B/W0>WG\X?+T[___>.T#PJ7]``)Q`.`#A^P``
M`&"`@>([`0`I.20?*GD``#_Y*E`]?:8#*7UX2RQ](02`3A@`0>@``#_I0/"I
M?]C_G$$X`.'K>?[_2P```&`@@"+I``"I+Q0`GD'^_V(\J!MC.`7Z_TL8`$'H
M0``A.`$`(#D```!@$``!Z.C_H>OP_\'K>($BF:8#"'P@`(!.````8```0F`"
M`$P\D%E".````&`H@"+I``"I+SP`GD&F`@A\````8/[_8CR(@8(XJ!MC.!``
M`?CA_R'XW?7_2Q@`0>@@`"$X$``!Z*8#"'Q`_O]+``!"8#C^_TL"`$P\/%E"
M.*8""'RY-`!(>1M\?+'_(?@``,`[(`""00```&`P@"+I``#`.WCCA7\``*GK
M``"]+QP`GD!0`"$X>//#?[@T`$@]`(DK%`">00$`I3@``"6)``"I+^S_GD!0
M*+Q\>".:?+0'OWQXZ[M_``#;ZP``OB_$_YY!>/OE?WCCA']X\\-_U?/_2Q@`
M0>@``*,O*`">0*[X/GT]`(DO'`">0%#8O7\!`/\[=!Z]?Q3ZWG\``+J3A/__
M2P@`>SNP__]+``````````&`!@```@!,/&Q80CBF`@A\$``!^)'_(?AD`($X
M\(\MZ6@`(?D``"`Y%?__2V@`(>GPCTWI>5(I?0``0#D,`()!T?;_2Q@`0>AP
M`"$X$``!Z*8#"'P@`(!.``````````&``````@!,/`Q80CBF`@A\\/_!^_C_
MX?MX&W]\$``!^('_(?CPCRWI:``A^0``(#ED`,$[>//$?WC[XW^A_O]+``"C
M+R``GD!H`"'I\(]-Z7E2*7T``$`Y/`""057V_TL8`$'H9@`AZ20?*7GX_TDY
M````8#"`(ND``"GI%%(I?1``2>D``*HO"0!)^?3_GD"D__]+@``A.%PS`$@`
M`````````8`"```"`$P\:%=".*8""'SA,@!(4?\A^'@;?WQX(YY\\(\MZ6@`
M(?D``"`Y```DB3T`B2\(`)Y``0#$.WCSPW_-\_]+&`!!Z&0`@3AX&WU\>/OC
M?^7]_TMY&WQ\3`""0:WS_TL8`$'H0.BC?_``G$$``$`YKE`^?0``J2^N43Q]
M`0!*.?#_GD```&`X:``AZ?"/3>EY4BE]``!`.70!@D%M]?]+&`!!Z````&`P
M@&+K```@.0``6^OX_QHYM`<\?0$`*3DD'RIY*E!(?0``JB_L_YY`````8+B!
M(H$"`)PXM`>$?"0?A'@``(DO)`">07C30W\9\?]+&`!!Z```HR\``'OX0`">
M0/__8#B`__]+`0`@.0```&!X(X-\N($BD6WV_TL8`$'H>1MY?-S_@D$D'X5[
M>--$?Y7W_TL8`$'H```[^P$`/#D``%OI````.20?*7DJ20I]9`"!DWC[Z7\`
M`$F)``"J+PP`GD$]`(HKD`">0&8`@>L```!@,(!BZU!(/WT"`'TXM`<I?11*
M8WP``%OK^?7_2Q@`0>@D'YQ[``"C+RKA>GQ@_YY!9@`AZ0``6^G___\[)!\I
M>2I(2GT!`#^-`0`*.0``J2\``"J9#`">03T`B2LP`)Y`/0`@.0``*ID``$`Y
MKE`^?0``J2^N42A]`0!*.?#_GD",_O]+`0`I.5S__TMX0PI]M/__2[``(3@4
M,0!(``````````&`!P```@!,/$A50CBF`@A\O3``2,'^(?AY&WU\\(\MZ?@`
M(?D``"`Y:`""00``/8D``(DO7`">077U_TL8`$'H>1M\?$P`@D'^_V(__O]"
M/_[_(C^%W7L[A-U:.X?=.3MH``$[>..#?^7N_TL8`$'H>1M_?#@`@D!XXX-_
M$?+_2Q@`0>AXZZ-_)?3_2Q@`0>CX`"'I\(]-Z7E2*7T``$`YU`""04GS_TL8
M`$'H$P#_.WC;9']X^^-_%?;_2Q@`0>@``*,OH/^>07C31']X^^-__?7_2Q@`
M0>@``*,OB/^>07CKHW\)\?]+&`!!Z'@;?GQX^^-_^?#_2Q@`0>@4\F-\`@!C
M.+0'8WQE]/]+&`!!Z'C[YG]XZZ5_>,LD?W@;?GP-\O]+&`!!Z'C#!']X\\-_
M/?#_2Q@`0>C__X,O>//#?R@`GD&``"&!)@0I50!`B2\8`)Y`N?[_2WCSPW_Q
M[O]+&`!!Z`#__TME]/]+&`!!Z.C__TM``2$XC"\`2``````````!@`@```(`
M3#S$4T(XI@((?/C_X?MX&W]\$``!^#'_(?@H`($X\(\MZ;@`(?D``"`Y6?'_
M2Q@`0>@``",L5`""0$``(8$F!"E5`$")*Q``GD'__RIM`*"*+QP`GD`"`(`X
M>/OC?T7N_TL8`$'H-`!C?'[98U2X`"'I\(]-Z7E2*7T``$`Y%`""0>'Q_TL8
M`$'H``!@..#__TO0`"$X%"\`2``````````!@`$```(`3#P<4T(XI@((?```
M`&`X@"+I$``!^.'_(?@``&F`/?'_2Q@`0>@```!@0("BZ/[_PCS^_X(\6-W&
M.(W=A#A]\_]+&`!!Z"``(3@0``'HI@,(?"``@$X``````````8`````"`$P\
MN%)".*8""'SX_^'[````8#B`XNL0``'XT?\A^```?X#5\/]+&`!!Z'G__TL`
M`'^`Q?#_2Q@`0>C^_^(\_O^B/!G@YSC^_X(\````.7@[YGS8O*4XJ=V$.#WN
M_TL8`$'H,``A.#@N`$@``````````8`!```"`$P\0%)".*8""'S)+0!(8=\A
M^```P#OPCRWI>"`A^0``(#F=[?]+&`!!Z&@`X3O^_\(\_O^"/'@;97R^W<8X
MPMV$.'C[XW]P$*$[U>__2Q@`0>AX^^-_`!"@.'CKI']A\/]+&`!!Z+0'?WP`
M`)\O-`"<00$`?SBT!V-\Y?'_2Q@`0>AY&WY\'`""07C[Y7]XZZ1_[>O_2Q@`
M0>@``"`YKOD^?7@@(>GPCTWI>5(I?0``0#EX\\-_#`""027P_TL8`$'HH"`A
M.$0M`$@``````````8`#```"`$P\:%%"."C__TL````````````````"`$P\
M4%%".*8""'PF@)!]"`"!D:TL`$BA[B'X>!M^?/[_8CS.W6,X>".??/"/+>GX
M$"'Y```@.;7X_TLO`(`X>!MZ?'CSPW]I[/]+&`!!Z```HR\T`)Y!_O]B/'CS
MQ'_7W6,XC?G_2_@0(>GPCTWI>5(I?0``0#EX\\-_>`&"07'O_TL8`$'H>//#
M?_[_@C]A[?]+&`!!Z.3=G#O^_R(_>..$?_[_XCZT!WM\>/OC?X'P_TL8`$'H
M_O_"/@``@#H``#HNA=TY.W@;?WP````[`0![.^;=]SK"WM8Z^`"A.V@`H3H`
M@)1B``"_+VS_GD$``#^)``")+P@`GD!XRS]_(`"207C[Y']XTT-_Q?'_2Q@`
M0>AXXX1_``"C+\@`GD%X^^-_S>S_2Q@`0>BT!V-\%!H_??__*8DO`(DOD`">
M010:>WS_#X,O$/^=07CSQW]XN^9^>/OE?WBSQ'YXZZ-_T>W_2Q@`0>AXJZ1^
M>.NC?P'L_TL8`$'H``"C+V``GD"``"&!)@0I50"@B7]0`)Y``0"`.'CKHW^9
MZO]+&`!!Z```HR\X`)Y`_O]B/'CKI'_7W6,X/?C_2WCKHW\5[?]+&`!!Z'@;
M?GR@_O]+__]C.+0'8WRN&1]_6/__2WCCA'\``&`X3>__2Q@`0>AX&W]\^/[_
M2V`1(3@(`(&!((&0??@J`$@``````````X`,``#__R,Y`0!)B0$`"3D``*HO
M(`">32\`BBL"`"DY"`">0'A+(WUX0PE]W/__2P````````````````(`3#P(
M3T(XI@((?/C_X?MY&W]\$``!^-'_(?@0`()!```_B0``B2\0`)Y`_O]B/(7=
M8S@0`0!(<>O_2Q@`0>C__R,Y%$J_?'@;:7P4&G]\__]C.$`8OW\,`)U!__^_
M+P@`GD`!`"`Y`0`I+/__*3FX`()!``!%B2\`BB^4`)Y!__]%.5`H/WU`4+]_
M"`"=0`$`(#D``$6)__\%.2\`BB]X`)Y`__]%.5`H/WU`4+]_#`"=0?__OR\(
M`)Y``0`@.0$`*2S__Z4X__\I.1``@D$``$6)+P"*+^C_GD%0*+]\``!@.`(`
M)3D`$*DK8`"=00```&`!`*4XP($B.7C[Y']X2R-]!>W_2Q@`0>A```!(__^E
M.%3__TL!`"DL>$,%??__*3EP_X)`0"B_?WC_GD```#^)_O]B/.;=8S@O`(DO
M[/Z>047K_TL8`$'H,``A.*`I`$@``````````8`!```"`$P\J$U".*8""'S^
M_T(]6-U*.?[_8CSHW6,X'2D`2%'_(?C^_\(__O^B/PG>WCO.W;T[_O_B/_[_
M@C\EWO\[+]Z<._"/+>F(`"'Y```@.0H`*CD``,GH"`#IZ!``">D8`$GI(``I
MH6``P?AH`.'X<``!^7@`0?F``"&Q*?7_2_[_8CSQW6,X'?7_2_[_8CSYW6,X
M$?7_2_[_8CP"WF,X!?7_2WCSPW_]]/]+_O]B/!G>8SCQ]/]+>.NC?^GT_TMX
M^^-_X?3_2WCC@W_9]/]+_O]B/#G>8SC-]/]+_O]B/-?=8SC!]/]+_O]B/$/>
M8SA5]/]+>1MD?`P`@D%XXX-_2?7_2_[_8CQ4WF,X.?3_2WD;9'P0`()!_O]B
M/&;>8S@I]?]+_O]B/''>8S@9]/]+>1MD?#@`@D%XZZ-_#?7_2_[_@CQX\\-_
MG=Z$./WT_TN(`"'I\(]-Z7E2*7T``$`Y4`""0>7J_TL8`$'H_O]B/('>8SC1
M\_]+>1MD?`P`@D%X^^-_N/__2_[_@CP*`*`XDMZ$.'$`83@QY_]+&`!!Z```
MHR^<_YY`>P"!.-3__TNP`"$XO"<`2``````````!@`0```(`3#SD2T(X````
M8`B!(H'__XDO8`">0*8""'S^_V(\)=YC.!```?BA_R'X5?/_2P``0#D``",L
M'`""00``(XD``*DO$`">03``*6G__TDQ$$E*?0```&!@`"$X"(%"D1```>@`
M``!@I@,(?`J!8N@@`(!.````8`J!8N@@`(!.``````````&``````@!,/%A+
M0CBF`@A\$``!^.'_(?B%ZO]+&`!!Z#WH_TL8`$'H```C+`@`@D$``&/H(``A
M.!```>BF`PA\(`"`3@`````````!@`````(`3#P,2T(XI@((?)$F`$B!_R'X
M_O_"/W@;?WR?WMX[>//#?X7R_TMX^^1_>1M]?!``@D$``#V)``")+Q0`GD!X
M\\-_:?/_2X``(3B()@!(G>?_2Q@`0>@``*,O[/^>0'C[XW])Y_]+&`!!Z'@;
M?'QXZZ-_.>?_2Q@`0>@4&GQ\`@!C.*GJ_TL8`$'H_O_"//[_@CS"WH0X>.NG
M?W@;?'SDW<8X>/OE?T7H_TL8`$'H>..$?XS__TL``````````8`$```"`$P\
M2$I".*8""'P``"`YF($I8;$E`$C__P`\_O\B/Q!^`&#.W3D[>!MZ?'C+(W]J
M`2%\%`HI?:"!X3OPCTWI``!)^0``0#D```!@$($BZ<!^/_D```!@&($BZ<A^
M/_D```!@(($BZ=!^/_D```!@*($BZ?!^/_D```!@,($BZ?A^/_D```!@.($B
MZ0!_/_D```!@0($BZ0A_/_D```!@2($BZ1!_/_D```!@4($BZ1A_/_D```!@
M6($BZ=A^/_D```!@8($BZ>!^/_D```!@:($BZ>A^/_D-\?]+>1M^?%``@D$`
M`#Z)``")+T0`GD%5_O]+>//#?]'F_TL8`$'H>!M^?```(#EX\\-_F($I810*
M*7T``$GI\(\MZ7E*2GT``"`YZ`6"0<'G_TL8`$'HR?W_2]!^OSMY&WY\D`&"
M07CSPW_^_X(_H>7_2Q@`0>C__]X[MMZ<.Z0/8W@!`&,X">G_2Q@`0>AX&WA\
M>!M]?`$`OHP``*4O;`&>0.A^WSL)`+[K``"]+SP`GD%XZZ-_5?#_2WD;?7SH
M_X)!```]B0``B2_<_YY!Y?3_2P``HR_0_YY!>.NC?Q'F_TL8`$'H>!M]?+A^
MGSL``+TO'`">0`D`W.L``+XO2`&>00``/HD``(DO&`&>0'CKHW_^_V(_^>3_
M2Q@`0>CFW7L[>!M^?'C#`W_EY/]+&`!!Z!3RPW\$!-X[M`?>?WCSPW]-Z/]+
M&`!!Z/[_XCS^_X(\>,,(?[O>YSAXVV9_>.NE?\#>A#AX&WQ\Y>7_2Q@`0>C`
M`8`X>..#?]7H_TL8`$'H__^#+\@`GD!%Y?]+&`!!Z`(`X^@1`(<OM`">00``
M`&!(@"+I``"ZZ/[_@CQXXX9_R=Z$.```:>C5X?]+&`!!Z```P#MD_O]+0>__
M2WD;:7P@`()!```IB0``B2\4`)Y!#>7_2Q@`0>AY&WY\>/Z"0`D`?>@``*,O
MT/^>0/[_PC^OWMX[8/[_2WCKHW]XXX1_/>7_2Q@`0>@"`+T[>/[_2WCSPW^-
M\_]+``"C+\C^GD%X\\-_N>3_2Q@`0>AX&WU\K/[_2P``H#O$_O]+('^?.'CC
M@W_9Y/]+&`!!Z'D;>'PL`()!````8$B`(ND``+KH_O^"/'CCAG\$WX0X``!I
MZ`WA_TL8`$'H./__2SA_/X$F!"E5`$")+\S_GD`\?[^##>;_2Q@`0>@`Z(-_
MN/^>0#A_/X'^!2E5P`&)+ZC_GD!X\\-_R>;_2Q@`0>AX&WY\_O]B/*K>8S@Q
M[O]+``"C+ZP!GD```/KJ>+OC?B'C_TL8`$'HM`=]?`,`G2^(`)U`_/]]./[_
M@CQ7WX0X%!IW?-WG_TL8`$'H``"C+V@`GD`$`)TO'`">0?S_O3NT![U_%.JW
M?___/8DO`(DO2`">0`@`NNL``+TO/`">07CKHW^]XO]+&`!!Z`,`HRLH`)U`
M_/]C./[_@CQ<WX0X%!I]?'WG_TL8`$'H``"C+P@`GD!XZ[=_#?K_2P``HR_P
M`9Y```"`.'B[XWZ5XO]+&`!!Z'D;?7S8`8)!`@"@..[_@#C]YO]+&`!!Z/A_
M7SL&`*`X>--$?WCKHW\%X/]+&`!!Z/A_/XD``(DOV`">0/E_/XE#`(DOS`">
M0/I_/XE!`(DOP`">0/M_/XE#`(DOM`">0/Q_/XE(`(DOJ`">0/U_/XE%`(DO
MG`">0`(`H#C&_X`X>.NC?XGF_TL8`$'H*0"@.'C31']XZZ-_E=__2Q@`0>C^
M_P(]>--'?QG@"#G^_X(\>-MF?WCCA7]AWX0X>//#?^WB_TL8`$'H>..#?P'@
M_TL8`$'H>//$?WC+(W^1[?]+>//#?^7Y_TN@^_]+``"ZZUWB_TL8`$'H>!MD
M?'CKHW^%\_]+>1MW?$#^@D`X_O]+``"@.```@#AXZZ-____@.NWE_TL8`$'H
M^'\?.R`$]U8I'`!(````8'@;>GQXN^5^>,,$?WCKHW_EWO]+&`!!Z+0'97P`
M`(4O<`"=07CKHW^P?[\[*>#_2Q@`0>AXTT1_>.NC?_[_XC[(?Q\[L1T`2```
M`&```$`[MM[W.J[0O7QXPP-_>+OD?@$`6CL"`!@[#>+_2Q@`0>@4`+HKX/^>
M0```(#G^_P(]&>`(.<A__SCP?S^9Z/[_2WC#!']XTT-_'1P`2````&!D__]+
M_O^"//[_8CR=WH0X)=YC.('L_TO^_^(__O^B/QG@_SM^W[T[3=__2Q@`0>C^
M_X(\>/OH?WC;9G]XXX5_>!MG?'#?A#AX\\-_B>'_2Q@`0>C``8`X>//#?WGD
M_TL8`$'H__^#+XC^GD#IX/]+&`!!Z```(X$1`(DO=/Z>0/7>_TL8`$'H`0`8
M.WC[Z7^T!QA_>-MF?W@;9WQXPPA_>..%?WCKI']X\\-_*>'_2Q@`0>B@__]+
M```AZ.P>`$@``````````8`)```"`$P\*$-".*8""'R='@!(8?\A^````&`X
M@.+K``!_@$GA_TL8`$'H>!M^?```?X`YX?]+&`!!Z+@`/HFY`".9_O]B/`G>
M8SA]ZO]+```C+!P`@D$``".),0")+Q``GD`!`".)``")+P@`GD$=]?]+``!_
M@````&"X@:([[>#_2Q@`0>C^_X(\"P#`.`$`H#B/WX0XE=[_2Q@`0>@``",L
ME`""0```?X#!X/]+&`!!Z/[_@CP#`,`X`0"@.)3?A#AIWO]+&`!!Z'D;?GQP
M`8)```!_@)7@_TL8`$'H_O^"/`,`P#@!`*`XF]^$.#W>_TL8`$'H>1M^?-0!
M@D'^_V(\U]UC.,'I_TMY&WQ\B`&"00``?X!5X/]+&`!!Z!``/NEXXX5_``")
MZ('<_TL8`$'HG`$`2!``(^D@`"`_`0#`.P`$.6,H`&GK"!`]@?__GCL``'^`
MM`><?P#PB7\H`)U`">#_2Q@`0>@``,`X>..%?WC;9']5X?]+&`!!Z'D;>GP@
M`()`````8,"1HH#__Z4X`."%?Q#_GD`!`,`[C```2!`07>DD'\E[*D@*?P``
M6ND,`"J!.$@I?P`$B2\H`)Y`$`"*Z'C#`W_AXO]+&`!!Z```HR^P_YY``0#>
M.[0'WG]H__]+``!_@('?_TL8`$'H``":Z`(`P#@``*`X[>#_2Q@`0>AX&V1\
MO/__2UW?_TL8`$'H>-MD?P$`WCNT!]Y_*=__2Q@`0>@($#V!``!_@`#PB7_8
M_YU!;/[_2P``?X`IW_]+&`!!Z!``/NG^_Z(\EM^E.```B>A1V_]+&`!!Z!``
M/ND``"GI#``I@4``*75@_H)!``!_@/'>_TL8`$'H$``^Z0``B>A!W/]+&`!!
MZ$#^_TM=[O]+>1M\?```?X#0`()!Q=[_2Q@`0>@0`#[I>..%?P``B>CQVO]+
M&`!!Z'CC@W]EV_]+&`!!Z```?X"9WO]+&`!!Z'@;?GP``'^`B=[_2Q@`0>C^
M_X(\`0"@.)W?A#AUW/]+&`!!Z/[_HCRRWZ4X>!MD?'CSPW^=VO]+&`!!Z```
M?X!1WO]+&`!!Z```(#FY`".9_O]B/,[=8SB5Y_]+````8```HR_0D6+X3`">
M0````&#(D6+HG?7_2P```&```*,OT)%B^#``GD#^_V(\N-]C."'<_TL8`$'H
M^=W_2Q@`0>@```!@R)%"Z1``/ND``*KHG/W_2P```&#0D6+HP`&`.''@_TL8
M`$'H$0"#+W@;9GPL`)Y!`0`C.0$`B2L@`)U`$!`]Z1@0O>C^_V(\V=]C.```
MB>B]V_]+&`!!Z*``(3@(&P!(``````````&`"````@!,/$`_0CBF`@A\\/_!
M^_C_X?MX&WY\$``!^)'_(?@A\/]+W>__2W@;?WPY\_]+``"C+U``GD$``+XO
M2`">00``/HD``(DO/`">0?[_@CQX^^-_N]Z$.,G;_TL8`$'H`!B_?R``GD!P
M`"$X>//#?Q```>CP_\'K^/_AZZ8#"'R`Z?]+<``A.)P:`$@``````````8`"
M```"`$P\J#Y".*8""'PX`,,X$1H`2`'](?CPCRWIJ`(A^0``(#D(`"`YI@,I
M?2@``3D``$;I+#0@?1``"#D(`,8X\/\H^2#"27DB`$=Y+@0I52!&2GEX4RE]
M*,#J>'A3*7T>0N=4>#LI??C_*/G$_P!"0``@.2```3FF`RE]<``HZ4@`Z.@8
M`$CI>#HI?7A2*7T)`$CI>%(I?:0/*GG"#REY>$M)?2``*7F``"CYT/\`0@``
M@^D@``/H$`"#Z!@`8^D(`*/H.`#!Z\(NB7FD+HIY>$M*?2@`(>F"\*AX(`!*
M>8):WC^9>=X[@EHI/10BWG^9>2DY%`(I?11*2GUX6HE\."@I?7A:*7T42DI]
M9/"I>'A#*7TP``'I(`!*>2``/WG"+D9Y>/J'?():"#TX8.=\F7D(.7@BYWP4
M6@A]%$+G?"@H2'EX,PA]@O"&>11"YWQD\(AY>#,(?2``YWAX0BE]PB[]>#A0
M*7T@``9Y>/HI?13R*7TH*/YX>.O>?Q3R*7UD\%YY@O!*>2``*7EX4\I_0`#!
MZWA2"'T@`%UY.#@(?8):WC]X,@A]F7G>.Q3Z_G_"+CYY%/H(?2@H/WEX\_]_
M%/H(?63P_WB"\.=X(``(>7@[YW](`.'K>#I*?2``_G@X2$I]@EK_/WCJ2GV9
M>?\[%#+??,(N'WD4,DI]*"@&>7C[QGP4,DI]9/`F>8+P*7D@`$IY>$O&?'@R
MZ7Q0`.'H(`#?>#A`*7UX\BE]@EKG/)EYYS@4ZJ=_*"A'>13J*7W"+EUY>.OG
M?!0Z*7UD\`=Y@O`(>2``*7EX0^=\>#K(?%@`P>@@`/UX.%`(?7CZ"'V"6L8\
MF7G&.!3RQG\H*"9Y%/((?<(N/GEX\\9\%#((?63P1GF"\$IY(``(>7A3QGQX
M,NI\8`#AZ"``WG@X2$I]>.I*?8):YSR9>><X%/KG?R@H!WD4^DI]PBX?>7C[
MYWP4.DI]9/`G>8+P*7D@`$IY>$OG?'@ZR7QH`,'H(`#_>#A`*7UX\BE]@EK&
M/)EYQC@4ZJ9_*"A&>13J*7W"+EUY>.O&?!0R*7UD\`9Y@O`(>2``*7EX0\9\
M>#+H?'``X>@@`-UX.%`(?7CZ"'V"6N<\F7GG.!3RQW\H*"=Y%/((?<(N/GEX
M\^=\%#H(?63P1WF"\$IY(``(>7A3YWQX.LI\>`#!Z"``_G@X2$I]>.I*?8):
MQCR9><8X%/KF?R@H!GD4^DI]PBX?>7C[QGP4,DI]9/`F>8+P*7D@`$IY>$O&
M?'@RZ7R``.'H(`#?>#A`*7UX\BE]@EKG/)EYYS@4ZJ=_*"A'>13J*7W"+EUY
M>.OG?!0Z*7UD\`=Y@O`(>2``*7EX0^=\>#K(?(@`P>@@`/UX.%`(?7CZ"'V"
M6L8\F7G&.!3RQG\H*"9Y%/((?<(N/GEX\\9\%#((?63P1GF"\$IY(``(>7A3
MQGQX,NI\D`#AZ"``WG@X2$I]>.I*?8):YSR9>><X%/KG?R@H!WD4^DI]PBX?
M>7C[YWP4.DI]9/`G>8+P*7D@`$IY>$OG?'@ZR7R8`,'H(`#_>#A`*7UX\BE]
M@EK&/)EYQC@4ZJ9_*"A&>13J*7W"+EUY>.O&?!0R*7UD\`9Y@O`(>2``*7EX
M0\9\>#+H?*``X>@@`-UX.%`(?7CZ"'V"6N<\F7GG.!3RQW\H*"=Y%/((?<(N
M/GEX\^=\%#H(?63P1WF"\$IY(``(>7A3YWQX.LI\J`#!Z"``_G@X2$I]>.I*
M?8):QCR9><8X%/KF?R@H!GD4^DI]PBX?>7C[QGP4,DI]9/`F>8+P*7D@`$IY
M>$O&?,(N7WEX,NE\L`#AZ"``W'@X0"E]>/(I?8):YSR9>><X%.JG?R@H1WEX
M^^=\%.HI?10Z*7UD\`=Y@O`(>2``*7EX0^A\PBX_>7A"QWRX`,'H9/!=>3A0
MYWR"\$IY>.+G?'A3JG_0`*'K@EK&/"``&WF9><8X>%((?13RQG\H*"9Y>/O&
M?!3RYWP4,N=\P`#!Z#A("'T@`/IX>-H(?<(N7WO:;KT_@EK&/*'KO3N9><8X
M%.*&?R@H1GL4X@A]9/`\>8+P*7EX^\9\>$N<?Q0R"'UXXD9](``9>7@ZQWS(
M`,'HPBXI>R@H/GL@`.=X>$O>?V3P7WO:;L8\@O!:>Z'KQCAXT_I_%-K&?'C2
MB7\4,N=\(`!*>13RYWQX0BA]V`#!ZR``^W@44KU_PBYI>R@H?WMX2_]_(``(
M>63P*7N"\#E[>,LY?11"'7UXRDE_%/H(?>``X>O:;MX_(``7>2``G'MX.B=]
MH>O>.\(NZGH4XMY_(`#G>"@HZ7H4.MY_>%,I?63P>'N"\'M[%$K>?WC;&'\@
M`-U[>,(I?R@HIGMX0BA]VF[_/\(NJ7L@`%I[>$O&?*'K_SOH`"'I%-+_?R``
M"'ED\/MZ@O#W>GB[>W\40O]_>-H*?Q0R_W_P`,'HVFXI/2``^GL@`#E[>/)>
M?:'K*3G"+DA[%,HI?2``WGLH*$I[%/(I?7A#2GUD\+Q[@O"]>Q12*7UXZYQ_
M(``W>7CB:G\H*.=Z>/I??<(NZGIX4^=\VF[&//@`0>D@`!A[9/!=>Z'KQCB"
M\%I[>-.]?Q3"QGP@`/][>.J(?Q3ZQGS:;DH]%#K&?"``>WL``>'H>$H)?:'K
M2CD@`-EX%-I*?2``*7DH*"A[%$I*?63P_GK"+BE[@O#W>GB[WG]X2PA]%$)*
M?7CRJ7_:;N<\(`!:>2``G'MX,B9]H>OG.,(N2'L4XN=\(`#&>"@H27L4,N=\
M>$,I?63P/WL(`0'I@O`Y>Q1*YWQXR_]_(`#X>'CZR7\H*`9[>%(J?<(N"7MX
M2\9\VFX(/1`!(>D@`+U[9/!;>Z'K"#F"\%I[>--[?Q3J"'T@`$IYVFXI/112
M"'UXVNI_%#((?2``WGL8`<'H>#I'?:'K*3D@`!EY%/(I?2``YW@H*"I[%#HI
M?<(N)WMX.TI]9/`<>X+P&'L44BE]>,.<?R``.GEXXFI_*"A'>WA"2'W"+DI[
M>%/G?-INQCP@`4'I(`#_>V3P/7NAZ\8X@O`Y>WC+O7\4^L9\(``(>=IN2CT4
M0L9\>.J(?Q0ZQGP@`'M[*`'AZ'A*"7VAZTHY(`#8>!3:2GT@`"EY*"@(>Q1*
M2GUD\%Y[PBX)>X+P6GMXT]Y_>$L(?11"2GUX\JE_VF[G/"``67D@`)Q[>#(F
M?:'KYSC"+BA[%.+G?"``QG@H*"E[%#+G?'A#*7UD\!][,`$!Z8+P&'L42N=\
M>,/_?R``^GAX^LE_*"A&>WA2*GW"+DE[>$O&?-IN"#TX`2'I(`"]>V3P.WNA
MZP@Y@O`Y>WC+>W\4Z@A](`!*>=IN*3T44@A]>-KJ?Q0R"'T@`-Y[0`'!Z'@Z
M1WVAZRDY(``8>13R*7T@`.=X*"@*>Q0Z*7W"+@=[>#M*?63P7'N"\%I[%%(I
M?7C3G'\@`#EY>.)J?R@H)WMX0DA]PBXJ>WA3YWS:;L8\2`%!Z2``_WMD\!U[
MH>O&.(+P&'MXP[U_%/K&?"``"'G:;DH]%$+&?'CJB'\4.L9\(`![>U`!X>AX
M2@E]H>M*.2``VG@4VDI](``I>2@H2'L42DI]PBY)>WA+"'UD\#Y[@O`Y>Q1"
M2GUXR]Y_(`!;>7CRJ7_"+FA[>#(F?=INYSPH*&E[(`"<>WA#*7VAZ^<X6`$!
MZ13BYWP@`,9X9/!?>X+P6GMXT_]_%#+G?!1*YWS:;@@]>/K)?R``O7MX4BI]
MH>L(.2``_'@4Z@A](`!*>2@HB7L44@A]PBZ*>WA3*7UD\&I[%$H(?6`!(>F"
M\'M[>-M*?2``WGMX4N9_(``(>=IN*3UX.L=\H>LI.2``YW@4\BE]PBX&>10Z
M*7TH*`=Y>#/G?&3PAGN"\)Q[(`!=>7CCQGP4.BE]:`&!ZR``WGAX,T=].$#G
M?#CPJG]X4^=\&X]`/=R\2F$@`/][(`!*>2``*7D4XHI_%/K\?\(N/'D4^N=\
M*"@_>7CC_W\4^N=\9/`?>8+P"'D@`.=X>$/_?R``_'MX^\A\.$@(?3C@QG]X
M,PA]<`'!Z!0RRGP4ZJ9_*"CF>!3J"'W"+OUX>.O&?!0R"'UD\"9Y@O`I>2``
M"'EX2\9\(`#=>'@SZ7\X."E]..B??WC[*7UX`>'K%/KJ?Q3RWW\H*!]Y%/(I
M?<(N'GEX\_]_%/HI?63P_WB"\.=X(``I>7@[YW\@`/YX>#O&?#CPOW\X0,9\
M>/O&?(`!X>L4^NI_%.*??R@H/WD4XL9\PBX\>7CC_W\4^L9\9/`?>8+P"'D@
M`,9X>$/H?R``'WEX0^=\./C<?SA(YWQXX^=\B`&!ZQ3BBG\4ZKQ_PB[<>!3J
MYWPH*-UX>..]?Q3JYWQD\#UY@O`I>2``YWAX2ZE_(``[>7A+"'TXV/U_.#`(
M?7CK"'V0`:'K%.JJ?Q3RW7_"+OUX%/((?2@H_GAXZ]Y_%/((?63PWGB"\,9X
M(``(>7@SWG\@`-U[>/,F?3@XQGPXZ&E_>$O&?)@!(>D42BI]%/KI?R@H"7D4
M^L9\PBX?>7C[*7UD\/]X%$K&?(+PYWB@`2'I>#O_?R``QG@@`/Q[>/O'?Q1*
M*GTXX+Y_.$#G?!3::7]X\^=\*"C)>,(NWG@4VN=\>/,I?11*YWQD\`EY@O`(
M>2``YWAX0RE](``^>7A+Z'\X,`A]./"??WC["'VH`>'K%/KJ?Q3JOW\H*/]X
M%.H(?<(N_7AXZ_]_%/H(?63PWWB"\,9X(``(>7@S_W\@`/U[>/LF?3@XQGPX
MZ,E_>$O&?+`!(>D42BI]%.*)?R@H"7D4XL9\PBX<>7CC*7T42L9\9/#I>(+P
MYW@@`,9X>#LI?2``/'EX2^=_.$#G?#C@OW]X^^=\N`'AZQ3ZZG\4\M]_*"C?
M>!3RYWS"+MYX>//_?Q3ZYWQD\!]Y@O`(>2``YWAX0_]_(`#^>WC[*'TX,`A]
M./")?WA+"'W``2'I%$HJ?13JJ7\H*.EX%.H(?<(N_7AXZRE]%$H(?63PR7B"
M\,9X(``(>7@S*7T@`#UY>$OF?S@XQGPXZ-]_>/O&?,@!X>L4^NI_%.*??R@H
M'WD4XL9\PBX<>7CC_W\4^L9\9/#_>(+PYW@@`,9X>#O_?R``_'MX^R=].$#G
M?#C@J7]X2^=\T`$AZ11**GT4\LE_*"C)>!3RYWS"+MYX>/,I?11*YWQD\`EY
M@O`(>2``YWAX0RE](``^>7A+Z'\X,`A]./"??WC["'W8`>'K%/KJ?Q3JOW\H
M*/]X%.H(?<(N_7AXZ_]_%/H(?63PWWB"\,9X(``(>7@S_W\@`/U[>/LF?3@X
MQGPXZ,E_>$O&?.`!(>D42BI]%.*)?R@H"7D4XL9\PBX<>7CC*7T42L9\9/#I
M>(+PYW@@`,9X>#LI?2``/'EX2^=_.$#G?#C@OW]X^^=\Z`'AZQ3ZZG\4\M]_
M*"C?>!3RYWS"+MYX>//_?Q3ZYWQD\!]Y@O`(>2``YWAX0_]_(`#^>WC[*'TX
M,`A]./")?WA+"'WP`2'I%$HJ?13JJ7\H*.EX%.H(?<(N_7AXZRE]%$H(?63P
MR7B"\,9X(``(>7@S)GT@`-UX>#/I?S@X*7TXZ-]_>/LI??@!X>L4^NI_%.*?
M?R@H'WD4XBE]PBX<>7CC_W\4^BE]9/#_>(+PYW@@`#MY>#OG?R``_'AX.\9\
M.."_?SA`QGQX^\9\``+AZQ3Z2GW"+G][%/)*?63P'GF"\`AY%%)&?7A#R'\H
M*&9[&`+!ZWC[QGQX0N=\%#)*?7A*YWP(`L'H8LH@/2``6'G6P2EAPBX?>R``
M*7D@`.=X%#+)?&3P&7L4ZJ9_*"@&>WC[QGP4ZN=\%#+G?&3P?WL0`L'H@O![
M>R``]WAXV_M_@O`8>WC:'7T4,LE\>%*J?Q3BAG\H*/]ZPB[F>B``2GEXPSE_
M>#/_?Q3B2GT4\LE_(``(>13Z2GT40MY_(`+AZWC*:'\@`%UY>#H'?63P^GJ"
M\/=ZPBZH>WB[6G\H**9[(`#G>'A#QGP4.OY\>-(H?Q0RYWP4^NE_*`+!Z"``
M>WMX4@I](`#^>!3:_W\@`$IY*"C(>Q12_W_"+LI[>%,(?63PO'N"\+U[%$+_
M?WCKG'\@`/=[>.)*?\(NZ'H4,LE\(``Y>W@Z1WTH*.IZ>$-*?13*QGPP`@'I
M(`#G>&3PW7N"\-Y[%#K&?'CSO7\44L9\>.J*?R``V'@40@E](`!:>WCZ7WT4
MT@A]PBX*>R``_WLH*`=[%/H(?7A3YWQD\/YZ.`)!Z8+P]WH4.@A]>+O>?R``
M&WEX\J=_*"A_>W@RYGS"+F=[>#O_?Q1227U``N'H(`"<>V3P&7N"\!A[%.)*
M?7C#.7\@`,9X%#)*?7C*QG\4^DI]%#KI?$@"X>L@`+U[>$+(?"``7'D4ZN=\
M(``(>63P>GN"\'M[%$+G?'C;6G_"+HA[*"B&>Q3ZZ7]X0\9\>-(H?Q0RYWP@
M`-Y[4`+!Z'A2"GT@`/UX%/+_?R``2GD44O]_*"BH>\(NJGMD\)M[>%,(?8+P
MG'MXXWM_%$+_?R``]GMXVDI_PB[(>A0RR7P@`#E[>#I'?2@HRGH4RL9\>$-*
M?2``YWA8`@'I9/"\>X+PO7MXZYQ_%#K&?!12QGQXXFI_(`#7>!1""7T@`%I[
M>/I??132"'W"+NIZ(`#_>R@HYWIX4^=\%/H(?6`"0>ED\-UZ@O#6>GBSO7\4
M.@A](``8>7CJAW]X,N9\*"@>>\(N!WL44DE]>#O>?R``>WMH`N'H9/#Y>H+P
M]WIXNSE_%-I*?2``QG@4.NE\%#)*?7C*IG\4\DI](`"<>W`"P>MX0LA\(`!6
M>13BYWP@``AY9/`:>X+P&'MXPUI_%$+G?"@HWWK"+LAZ>$/_?WC2*'\4^N=\
M%/+)?W@"X>L@`+U[>%(*?2``]W@4ZMY_(`!*>2@HZ'H44MY_9/#;>L(NZGJ"
M\-9Z>%,(?7BS>W]XVDI_%$+>?X`"`>D@`-A[%/KI?R``.7MX.D=]%,K_?\(N
M"GL@`.=X*"@&>V3P_'J"\/=Z>%/&?'B[G'\4.O]_>.)J?Q0R_W\40@E]B`+!
MZ"``^7L@`%I[>/)>?132"'W"+BI[(`#>>R@H)WL4\@A]>%/G?&3P'7N"\!A[
M%#H(?7C#O7\@`!IY>.J*?\(N1WL4,LE\(`![>WCZ7WTH*$I[>#M*?13:QGR0
M`N'H(`#_>V3P/GN"\#E[%/K&?'C+WG\44L9\>/*J?Q0ZZ7P@`)Q[>$)(?2``
MVW@4XN=\H`*!ZR``"'DH*&I[%$+G?,(N:'MX0TI]9/!?>Q12YWR8`D'I@O!:
M>WC3_W\@`+U[(`#H>!0"'WP44DE]%.(I?13J2GUX^MU_>#*F?\(N'7D@`,9X
M(`#>>Q0R2GTH*`9Y>.O&?!3R*7T4,DI]9/!F>X+P>WL@`$IY>-O&?(+P'7EX
M,OY_*/`(>7@ZQW_"+EYY(`#G>'CK"'T4.BE]*"A'>7CSYWP44J5\%#HI?10B
MB'P48BE]%%IF?2``*7D@`*5X(`"$>"``:WD@``!X```C^0@`H_@0`(/X&`!C
M^2```_BH`B'I\(]-Z7E2*7T``$`Y#`""03G'_TL8`$'H``,A.#P$`$@`````
M`````8`*```"`$P\?"A".*8""'R``&`X$``!^.'_(?B%R/]+&`!!Z$5G0#T@
M`"$X`2-*80``0_G-[T`]B:M*82``2GD(`$/YNIA`/?[<2F$@`$IY$`!#^3(0
M0#UV5$IA&`!#^=+#0#WPX4IA(`!*>2``0_D``$`Y>`!#D2@`0_DP`$/Y$``!
MZ*8#"'P@`(!.``````````&``````@!,/.@G0CBF`@A\)!^I>&$#`$BQ_R'X
M>!M^?'@CGWQX*[U\*`!#Z112*7T@`"EY0$BJ?Q``G4`P`$/I`0!*.3``0_EZ
M`'[H,`!>Z2@`/OE"'ZE[.`">.P``HR\42BI],``^^5@`GD%``",A>.N[?P!(
MG7\(`)U`>$L[?;0'>G]X^^1_>--%?Q0:?'R=P?]+&`!!Z'@`/H$4VBE]0`")
M+W@`/I$X`)Y`4.B[?Q32_W^T![U_>//#?Y'H_TL_`)TO)`"=07CKI7]X^^1_
M>..#?UG!_TL8`$'H>`"^DU``(3C(`@!(``#_Z`@`'^D0`%_I&``_Z<#_O3M`
M`/\[M`>]?P``_/@(`!SY$`!<^1@`//G@___HZ/\?Z?#_7^GX_S_I(`#\^"@`
M'/DP`%SY.``\^83__TL``````````8`&```"`$P\J"9".*8""'PH`"0Y@/]`
M.2$"`$BQ_R'X.`"D.W@;?GQX(Y]\*`"DZ"Q,@'\P`"0Y+$Q@?[[NI52T!ZE\
M`0"E.#@`A2^T!Z-\KDE=?10:?7PT`9U`0`"E(```@#BT!Z5\Y</_2Q@`0>AX
M^^-_F>?_2S@`H#@``(`X>.NC?\G#_TL8`$'H<`!_DW0`GY-X^^-_=>?_2P``
M/^EX^^-_`D8I>0``/ID``#_I`H0I>0$`/ID``#_I`L(I>0(`/ID``#_I`P`^
MF0@`/^D"1BEY!``^F0@`/^D"A"EY!0`^F0@`/^D"PBEY!@`^F0@`/^D'`#Z9
M$``_Z0)&*7D(`#Z9$``_Z0*$*7D)`#Z9$``_Z0+"*7D*`#Z9$``_Z0L`/ID8
M`#_I`D8I>0P`/ID8`#_I`H0I>0T`/ID8`#_I`L(I>0X`/ID8`#_I#P`^F2``
M/^D"1BEY$``^F2``/^D"A"EY$0`^F2``/^D"PBEY$@`^F2``/^D3`#Z9,<#_
M2Q@`0>A0`"$XZ```2#@`I2```(`XM`>E?.S^_TL``````````8`%``````!@
M`@!,/``E0CC__R(]*'PIZ?C_X?O__^(_T?\A^#!\_SO__ZDO0`">0:8""'P8
M`$'X^/__.T```?@```!@``!"8*8#*7UX2RQ](02`3A@`0>CY_S_I__^I+^C_
MGD!```'HI@,(?#``(3CX_^'K(`"`3J#_@?JH_Z'ZL/_!^KC_X?K`_P'[R/\A
M^]#_0?O8_V'[X/^!^^C_H?OP_\'[^/_A^Q```?@@`(!.H/^!ZJC_H>JP_\'J
MN/_AZL#_`>O(_R'KT/]!Z]C_8>O@_X'K$``!Z.C_H>NF`PA\\/_!Z_C_X>L@
M`(!.\/_!ZQ```>CX_^'KI@,(?"``@$X`H@$``````*8""'P%`)]"I@)H?1@`
M0?CP_TOHI@,(?%!@BWT46F)]T/\,.```B^F"\`!XI@.)?0@`:^D@!(!.R/__
M2\3__TO`__]+O/__2[C__TNT__]+L/__2ZS__TNH__]+I/__2Z#__TN<__]+
MF/__2Y3__TN0__]+C/__2XC__TN$__]+@/__2WS__TMX__]+=/__2W#__TML
M__]+:/__2V3__TM@__]+7/__2UC__TM4__]+4/__2TS__TM(__]+1/__2T#_
M_TL\__]+./__2S3__TLP__]++/__2RC__TLD__]+(/__2QS__TL8__]+%/__
M2Q#__TL,__]+"/__2P3__TL`__]+_/[_2_C^_TOT_O]+\/[_2^S^_TOH_O]+
MY/[_2^#^_TO<_O]+V/[_2P(`3#S4(D(XI@((?!```?CA_R'X*<C_2P```&`@
M`"$X$``!Z*8#"'P@`(!.<&5R;'AS:2YC`%]?14Y67U!!4E]#3$5!3E]?("`@
M("`@("`@("`@("`@```N+@`E<R\E<P!$>6YA3&]A9&5R.CIB;V]T7T1Y;F%,
M;V%D97(`26YT97)N86QS.CI005(Z.D)/3U0`97AE`"]P<F]C+R5I+R5S`%!!
M4E]414U0`%!!4E]04D]'3D%-10`Z`"\`4$523#5,24(`4$523$Q)0@!015),
M-4]05`!015),24\`4$%27TE.251)04Q)6D5$`%!!4E]34$%73D5$`%!!4E]#
M3$5!3@!005)?1$5"54<`4$%27T-!0TA%`%!!4E]'3$]"04Q?1$5"54<`4$%2
M7T=,3T)!3%]435!$25(`4$%27U1-4$1)4@!005)?1TQ/0D%,7U1%35``4$%2
M7T=,3T)!3%]#3$5!3@!005)?0TQ%04X]`#$`3$1?3$E"4D%265]0051(`%-9
M4U1%30`E,#)X`'!A<BT`)7,E<R5S)7,`)7,Z(&-R96%T:6]N(&]F('!R:79A
M=&4@<W5B9&ER96-T;W)Y("5S(&9A:6QE9"`H97)R;F\])6DI"@`E<SH@<')I
M=F%T92!S=6)D:7)E8W1O<GD@)7,@:7,@=6YS869E("AP;&5A<V4@<F5M;W9E
M(&ET(&%N9"!R971R>2!Y;W5R(&]P97)A=&EO;BD*`'!A<FP`+G!A<@`E<R5S
M8V%C:&4M)7,E<P`E<R5S=&5M<"TE=25S`"5S)7-T96UP+25U+25U)7,`05)'
M5@`8`'!E<FP`,`!005(Z.E!A8VME<CHZ5D524TE/3@`Q+C`T.0!5;F%B;&4@
M=&\@8W)E871E(&-A8VAE(&1I<F5C=&]R>0`E<SH@8W)E871I;VX@;V8@<')I
M=F%T92!C86-H92!S=6)D:7)E8W1O<GD@)7,@9F%I;&5D("AE<G)N;STE:2D*
M`"UE`"TM`%5315(`55-%4DY!344`5$5-4$1)4@!435``+W1M<`!E=F%L("=E
M>&5C("]U<W(O8FEN+W!E<FP@("U3("0P("1[,2LB)$`B?2<*:68@,#L@(R!N
M;W0@<G5N;FEN9R!U;F1E<B!S;VUE('-H96QL"G!A8VMA9V4@7U]P87)?<&P[
M"FUY("@D4$%27TU!1TE#+"`D<&%R7W1E;7`L("1P<F]G;F%M92P@0'1M<&9I
M;&4I.PI%3D0@>R!I9B`H)$5.5GM005)?0TQ%04Y]*2!["G)E<75I<F4@1FEL
M93HZ5&5M<#L*<F5Q=6ER92!&:6QE.CI"87-E;F%M93L*<F5Q=6ER92!&:6QE
M.CI3<&5C.PIM>2`D=&]P9&ER(#T@1FEL93HZ0F%S96YA;64Z.F1I<FYA;64H
M)'!A<E]T96UP*3L*;W5T<RAQ<7M296UO=FEN9R!F:6QE<R!I;B`B)'!A<E]T
M96UP(GTI.PI&:6QE.CI&:6YD.CIF:6YD9&5P=&@H<W5B('L@*"`M9"`I(#\@
M<FUD:7(@.B!U;FQI;FL@?2P@)'!A<E]T96UP*3L*<FUD:7(@)'!A<E]T96UP
M.PII9B`H+60@)'!A<E]T96UP("8F("1>3R!N92`G35-7:6XS,B<I('L*;7D@
M)'1M<"`](&YE=R!&:6QE.CI496UP*`I414U03$%412`]/B`G=&UP6%A86%@G
M+`I$25(@/3X@1FEL93HZ0F%S96YA;64Z.F1I<FYA;64H)'1O<&1I<BDL"E-5
M1D9)6"`]/B`G+F-M9"<L"E5.3$E.2R`]/B`P+`HI.PIP<FEN="`D=&UP("(C
M(2]B:6XO<V@*>#TQ.R!W:&EL92!;(%PD>"`M;'0@,3`@73L@9&\*<FT@+7)F
M("<D<&%R7W1E;7`G"FEF(%L@7"$@+60@)R1P87)?=&5M<"<@73L@=&AE;@IB
M<F5A:PIF:0IS;&5E<"`Q"G@]8&5X<'(@7"1X("L@,6`*9&]N90IR;2`G(B`N
M("1T;7`M/F9I;&5N86UE("X@(B<*(CL*8VAM;V0@,#<P,"PD=&UP+3YF:6QE
M;F%M93L*;7D@)&-M9"`]("1T;7`M/F9I;&5N86UE("X@)R`^+V1E=B]N=6QL
M(#(^)C$@)B<["F-L;W-E("1T;7`["G-Y<W1E;2@D8VUD*3L*;W5T<RAQ<2A3
M<&%W;F5D(&)A8VMG<F]U;F0@<')O8V5S<R!T;R!P97)F;W)M(&-L96%N=7`Z
M("D*+B`D=&UP+3YF:6QE;F%M92D["GT*?2!]"D)%1TE.('L*26YT97)N86QS
M.CI005(Z.D)/3U0H*2!I9B!D969I;F5D("9);G1E<FYA;',Z.E!!4CHZ0D]/
M5#L*)%!!4E]-04=)0R`](")<;E!!4BYP;5QN(CL*979A;"!["E]P87)?:6YI
M=%]E;G8H*3L*;7D@)'%U:65T(#T@(21%3E9[4$%27T1%0E5'?3L*;7D@)4-O
M;F9I9R`]("@*<&%T:%]S97`@("`@/3X@*"1>3R`]?B`O7DU35VEN+R`_("<[
M)R`Z("<Z)RDL"E]E>&4@("`@("`@(#T^("@D7D\@/7X@+UXH/SI-4U=I;GQ/
M4S)\8WEG=VEN*2\@/R`G+F5X92<@.B`G)RDL"E]D96QI;2`@("`@(#T^("@D
M7D\@/7X@+UY-4U=I;GQ/4S(O(#\@)UQ<)R`Z("<O)RDL"BD["E]S971?<')O
M9VYA;64H*3L*7W-E=%]P87)?=&5M<"@I.PIM>2`H)'-T87)T7W!O<RP@)&1A
M=&%?<&]S*3L*>PIL;V-A;"`D4TE'>U]?5T%23E]??2`]('-U8B![?3L*;W!E
M;B!?1D@L("<\)RP@)'!R;V=N86UE(&]R(&QA<W0["F)I;FUO9&4H7T9(*3L*
M;7D@)&)U9CL*;7D@)'-I>F4@/2`M<R`D<')O9VYA;64["FUY("1C:'5N:U]S
M:7IE(#T@-C0@*B`Q,#(T.PIM>2`D;6%G:6-?<&]S.PII9B`H)'-I>F4@/#T@
M)&-H=6YK7W-I>F4I('L*)&UA9VEC7W!O<R`](#`["GT@96QS:68@*"AM>2`D
M;2`]("1S:7IE("4@)&-H=6YK7W-I>F4I(#X@,"D@>PHD;6%G:6-?<&]S(#T@
M)'-I>F4@+2`D;3L*?2!E;'-E('L*)&UA9VEC7W!O<R`]("1S:7IE("T@)&-H
M=6YK7W-I>F4["GT*=VAI;&4@*"1M86=I8U]P;W,@/CT@,"D@>PIS965K*%]&
M2"P@)&UA9VEC7W!O<RP@,"D["G)E860H7T9(+"`D8G5F+"`D8VAU;FM?<VEZ
M92`K(&QE;F=T:"@D4$%27TU!1TE#*2D["FEF("@H;7D@)&D@/2!R:6YD97@H
M)&)U9BP@)%!!4E]-04=)0RDI(#X](#`I('L*)&UA9VEC7W!O<R`K/2`D:3L*
M;&%S=#L*?0HD;6%G:6-?<&]S("T]("1C:'5N:U]S:7IE.PI]"FQA<W0@:68@
M)&UA9VEC7W!O<R`\(#`["G-E96L@7T9(+"`D;6%G:6-?<&]S("T@-"P@,#L*
M<F5A9"!?1D@L("1B=68L(#0["G-E96L@7T9(+"`D;6%G:6-?<&]S("T@-"`M
M('5N<&%C:R@B3B(L("1B=68I+"`P.PHD9&%T85]P;W,@/2!T96QL(%]&2#L*
M;7D@)7)E<75I<F5?;&ES=#L*<F5A9"!?1D@L("1B=68L(#0[("`@("`@("`@
M("`@("`@("`@("`@("`@("`@(R!R96%D('1H92!F:7)S="`B1DE,12(*=VAI
M;&4@*"1B=68@97$@(D9)3$4B*2!["G)E860@7T9(+"`D8G5F+"`T.PIR96%D
M(%]&2"P@)&)U9BP@=6YP86-K*").(BP@)&)U9BD["FUY("1F=6QL;F%M92`]
M("1B=68["F]U=',H<7$H56YP86-K:6YG(&9I;&4@(B1F=6QL;F%M92(N+BXI
M*3L*;7D@)&-R8R`]("@@)&9U;&QN86UE(#U^('-\7BA;82UF7&1=>SA]*2]\
M?"`I(#\@)#$@.B!U;F1E9CL*;7D@*"1B87-E;F%M92P@)&5X="D@/2`H)&)U
M9B`]?B!M?"@_.BXJ+RD_*"XJ*2A<+BXJ*7PI.PIR96%D(%]&2"P@)&)U9BP@
M-#L*<F5A9"!?1D@L("1B=68L('5N<&%C:R@B3B(L("1B=68I.PII9B`H9&5F
M:6YE9"@D97AT*2!A;F0@)&5X="`A?B`O7"XH/SIP;7QP;'QI>'QA;"DD+VDI
M('L*;7D@)&9I;&5N86UE(#T@7W1E;7!F:6QE*"(D8W)C)&5X="(L("1B=68L
M(#`W-34I.PHD4$%2.CI(96%V>3HZ1G5L;$-A8VAE>R1F=6QL;F%M97T@/2`D
M9FEL96YA;64["B1005(Z.DAE879Y.CI&=6QL0V%C:&5[)&9I;&5N86UE?2`]
M("1F=6QL;F%M93L*?0IE;'-I9B`H("1F=6QL;F%M92`]?B!M?%XO/W-H;&EB
M+WP@86YD(&1E9FEN960@)$5.5GM005)?5$5-4'T@*2!["FUY("1F:6QE;F%M
M92`](%]T96UP9FEL92@B)&)A<V5N86UE)&5X="(L("1B=68L(#`W-34I.PIO
M=71S*")32$Q)0CH@)&9I;&5N86UE7&XB*3L*?0IE;'-E('L*)')E<75I<F5?
M;&ES='LD9G5L;&YA;65](#T*)%!!4CHZ2&5A=GDZ.DUO9'5L94-A8VAE>R1F
M=6QL;F%M97T@/2!["F)U9B`]/B`D8G5F+`IC<F,@/3X@)&-R8RP*;F%M92`]
M/B`D9G5L;&YA;64L"GT["GT*<F5A9"!?1D@L("1B=68L(#0["GT*;&]C86P@
M0$E.0R`]("AS=6(@>PIM>2`H)'-E;&8L("1M;V1U;&4I(#T@0%\["G)E='5R
M;B!I9B!R968@)&UO9'5L92!O<B`A)&UO9'5L93L*;7D@)&EN9F\@/2!D96QE
M=&4@)')E<75I<F5?;&ES='LD;6]D=6QE?2!O<B!R971U<FX["B1)3D-[)&UO
M9'5L97T@/2`B+VQO861E<B\D:6YF;R\D;6]D=6QE(CL*:68@*"1%3E9[4$%2
M7T-,14%.?2!A;F0@9&5F:6YE9"@F24\Z.D9I;&4Z.FYE=RDI('L*;7D@)&9H
M(#T@24\Z.D9I;&4M/FYE=U]T;7!F:6QE(&]R(&1I92`D(3L*8FEN;6]D92@D
M9F@I.PIP<FEN="`D9F@@)&EN9F\M/GMB=69].PIS965K*"1F:"P@,"P@,"D[
M"G)E='5R;B`D9F@["GT*96QS92!["FUY("1F:6QE;F%M92`](%]T96UP9FEL
M92@B)&EN9F\M/GMC<F-]+G!M(BP@)&EN9F\M/GMB=69]*3L*;W!E;B!M>2`D
M9F@L("<\)RP@)&9I;&5N86UE(&]R(&1I92`B8V%N)W0@<F5A9"`D9FEL96YA
M;64Z("0A(CL*8FEN;6]D92@D9F@I.PIR971U<FX@)&9H.PI]"F1I92`B0F]O
M='-T<F%P<&EN9R!F86EL960Z(&-A;FYO="!F:6YD("1M;V1U;&4A7&XB.PI]
M+"!`24Y#*3L*<F5Q=6ER92!84TQO861E<CL*<F5Q=6ER92!005(Z.DAE879Y
M.PIR97%U:7)E($-A<G`Z.DAE879Y.PIR97%U:7)E($5X<&]R=&5R.CI(96%V
M>3L*4$%2.CI(96%V>3HZ7VEN:71?9'EN86QO861E<B@I.PIR97%U:7)E($E/
M.CI&:6QE.PIW:&EL92`H;7D@)&9I;&5N86UE(#T@*'-O<G0@:V5Y<R`E<F5Q
M=6ER95]L:7-T*5LP72D@>PIU;FQE<W,@*"1)3D-[)&9I;&5N86UE?2!O<B`D
M9FEL96YA;64@/7X@+T)31%!!3B\I('L*:68@*"1F:6QE;F%M92`]?B`O7"YP
M;6,_)"]I*2!["G)E<75I<F4@)&9I;&5N86UE.PI]"F5L<V4@>PID;R`D9FEL
M96YA;64@=6YL97-S("1F:6QE;F%M92`]?B`O<VET96-U<W1O;6EZ95PN<&PD
M+SL*?0I]"F1E;&5T92`D<F5Q=6ER95]L:7-T>R1F:6QE;F%M97T["GT*;&%S
M="!U;FQE<W,@)&)U9B!E<2`B4$M<,#`S7#`P-"(["B1S=&%R=%]P;W,@/2`H
M=&5L;"!?1D@I("T@-#L@("`@("`@("`@("`@("`@(R!S=&%R="!O9B!Z:7`*
M?0IM>2!`<&%R7V%R9W,["FUY("@D;W5T+"`D8G5N9&QE+"`D;&]G9F@L("1C
M86-H95]N86UE*3L*9&5L971E("1%3E9[4$%27T%04%]2155317T[(",@<V%N
M:71I>F4@*%)%55-%(&UA>2!B92!A('-E8W5R:71Y('!R;V)L96TI"B1Q=6EE
M="`](#`@=6YL97-S("1%3E9[4$%27T1%0E5'?3L*:68@*"$D<W1A<G1?<&]S
M(&]R("@D05)'5ELP72!E<2`G+2UP87(M;W!T:6]N<R<@)B8@<VAI9G0I*2![
M"FUY("5D:7-T7V-M9"`]('%W*`IP("`@8FQI8E]T;U]P87(*:2`@(&EN<W1A
M;&Q?<&%R"G4@("!U;FEN<W1A;&Q?<&%R"G,@("!S:6=N7W!A<@IV("`@=F5R
M:69Y7W!A<@HI.PII9B`H0$%21U8@86YD("1!4D=66S!=(&5Q("<M+7)E=7-E
M)RD@>PIS:&EF="!`05)'5CL*)$5.5GM005)?05!07U)%55-%?2`]('-H:69T
M($!!4D=6.PI]"F5L<V4@>R`C(&YO<FUA;"!P87)L(&)E:&%V:6]U<@IM>2!`
M861D7W1O7VEN8SL*=VAI;&4@*$!!4D=6*2!["B1!4D=66S!=(#U^("]>+2A;
M04E-3T),8G%P:75S5'9=*2@N*BDO(&]R(&QA<W0["FEF("@D,2!E<2`G22<I
M('L*<'5S:"!`861D7W1O7VEN8RP@)#(["GT*96QS:68@*"0Q(&5Q("=-)RD@
M>PIE=F%L(")U<V4@)#(B.PI]"F5L<VEF("@D,2!E<2`G02<I('L*=6YS:&EF
M="!`<&%R7V%R9W,L("0R.PI]"F5L<VEF("@D,2!E<2`G3R<I('L*)&]U="`]
M("0R.PI]"F5L<VEF("@D,2!E<2`G8B<I('L*)&)U;F1L92`]("=S:71E)SL*
M?0IE;'-I9B`H)#$@97$@)T(G*2!["B1B=6YD;&4@/2`G86QL)SL*?0IE;'-I
M9B`H)#$@97$@)W$G*2!["B1Q=6EE="`](#$["GT*96QS:68@*"0Q(&5Q("=,
M)RD@>PIO<&5N("1L;V=F:"P@(CX^(BP@)#(@;W(@9&EE(")86%@Z($-A;FYO
M="!O<&5N(&QO9SH@)"$B.PI]"F5L<VEF("@D,2!E<2`G5"<I('L*)&-A8VAE
M7VYA;64@/2`D,CL*?0IS:&EF="A`05)'5BD["FEF("AM>2`D8VUD(#T@)&1I
M<W1?8VUD>R0Q?2D@>PID96QE=&4@)$5.5GLG4$%27U1%35`G?3L*:6YI=%]I
M;F,H*3L*<F5Q=6ER92!005(Z.D1I<W0["B9[(E!!4CHZ1&ES=#HZ)&-M9")]
M*"D@=6YL97-S($!!4D=6.PHF>R)005(Z.D1I<W0Z.B1C;60B?2@D7RD@9F]R
M($!!4D=6.PIE>&ET.PI]"GT*=6YS:&EF="!`24Y#+"!`861D7W1O7VEN8SL*
M?0I]"FEF("@D;W5T*2!["GL*<F5Q=6ER92!)3SHZ1FEL93L*<F5Q=6ER92!!
M<F-H:79E.CI::7`["G)E<75I<F4@1&EG97-T.CI32$$["GT*;7D@)'!A<B`]
M('-H:69T*$!!4D=6*3L*;7D@)'II<#L*:68@*&1E9FEN960@)'!A<BD@>PIO
M<&5N(&UY("1F:"P@)SPG+"`D<&%R(&]R(&1I92`B0V%N;F]T(&9I;F0@)R1P
M87(G.B`D(2(["F)I;FUO9&4H)&9H*3L*8FQE<W,H)&9H+"`G24\Z.D9I;&4G
M*3L*)'II<"`]($%R8VAI=F4Z.EII<"T^;F5W.PHH("1Z:7`M/G)E861&<F]M
M1FEL94AA;F1L92@D9F@L("1P87(I(#T]($%R8VAI=F4Z.EII<#HZ05I?3TLH
M*2`I"F]R(&1I92`B4F5A9"`G)'!A<B<@97)R;W(Z("0A(CL*?0IM>2`E96YV
M(#T@9&\@>PII9B`H)'II<"!A;F0@;7D@)&UE=&$@/2`D>FEP+3YC;VYT96YT
M<R@G345402YY;6PG*2D@>PHD;65T82`]?B!S+RXJ7G!A<CHD+R]M<SL*)&UE
M=&$@/7X@<R]>7%,N*B\O;7,["B1M971A(#U^("]>("`H6UXZ72LI.B`H+BLI
M)"]M9SL*?0I].PIL;V-A;"`D+R`](%PT.PII9B`H9&5F:6YE9"`D<&%R*2![
M"F]P96X@4$%2+"`G/"<L("1P87(@;W(@9&EE("(D(3H@)'!A<B(["F)I;FUO
M9&4H4$%2*3L*9&EE("(D<&%R(&ES(&YO="!A(%!!4B!F:6QE(B!U;FQE<W,@
M/%!!4CX@97$@(E!+7#`P,UPP,#0B.PI]"D-R96%T95!A=&@H)&]U="D@.PIM
M>2`D9F@@/2!)3SHZ1FEL92T^;F5W*`HD;W5T+`I)3SHZ1FEL93HZ3U]#4D5!
M5"@I('P@24\Z.D9I;&4Z.D]?5U)/3DQ9*"D@?"!)3SHZ1FEL93HZ3U]44E5.
M0R@I+`HP-S<W+`HI(&]R(&1I92`D(3L*8FEN;6]D92@D9F@I.PHD+R`]("AD
M969I;F5D("1D871A7W!O<RD@/R!<)&1A=&%?<&]S(#H@=6YD968["G-E96L@
M7T9(+"`P+"`P.PIM>2`D;&]A9&5R(#T@<V-A;&%R(#Q?1D@^.PII9B`H(21%
M3E9[4$%27U9%4D)!5$E-?2!A;F0@)&QO861E<B`]?B`O7B@_.B,A?%Q`<F5M
M*2\I('L*<F5Q=6ER92!005(Z.D9I;'1E<CHZ4&]D4W1R:7`["E!!4CHZ1FEL
M=&5R.CI0;V13=')I<"T^;F5W+3YA<'!L>2A<)&QO861E<BP@)#`I"GT*9F]R
M96%C:"!M>2`D:V5Y("AS;W)T(&ME>7,@)65N=BD@>PIM>2`D=F%L(#T@)&5N
M=GLD:V5Y?2!O<B!N97AT.PHD=F%L(#T@979A;"`D=F%L(&EF("1V86P@/7X@
M+UY;)R)=+SL*;7D@)&UA9VEC(#T@(E]?14Y67U!!4E\B("X@=6,H)&ME>2D@
M+B`B7U\B.PIM>2`D<V5T(#T@(E!!4E\B("X@=6,H)&ME>2D@+B`B/21V86PB
M.PHD;&]A9&5R(#U^('-[)&UA9VEC*"`K*7U["B1M86=I8R`N("1S970@+B`H
M)R`G('@@*&QE;F=T:"@D,2D@+2!L96YG=&@H)'-E="DI*0I]96<["GT*)&9H
M+3YP<FEN="@D;&]A9&5R*3L*)"\@/2!U;F1E9CL*:68@*"1B=6YD;&4I('L*
M<F5Q=6ER92!005(Z.DAE879Y.PI005(Z.DAE879Y.CI?:6YI=%]D>6YA;&]A
M9&5R*"D["FEN:71?:6YC*"D["G)E<75I<F5?;6]D=6QE<R@I.PIM>2!`:6YC
M(#T@9W)E<"![("$O0E-$4$%.+R!]"F=R97`@>PHH)&)U;F1L92!N92`G<VET
M92<I(&]R"B@D7R!N92`D0V]N9FEG.CI#;VYF:6=[87)C:&QI8F5X<'T@86YD
M"B1?(&YE("1#;VYF:6<Z.D-O;F9I9WMP<FEV;&EB97AP?2D["GT@0$E.0SL*
M;7D@)69I;&5S.PHD9FEL97-[)%]]*RL@9F]R($!$>6YA3&]A9&5R.CID;%]S
M:&%R961?;V)J96-T<RP@=F%L=65S("5)3D,["FUY("1L:6)?97AT(#T@)$-O
M;F9I9SHZ0V]N9FEG>VQI8E]E>'1].PIM>2`E=W)I='1E;CL*9F]R96%C:"`H
M<V]R="!K97ES("5F:6QE<RD@>PIM>2`H)&YA;64L("1F:6QE*3L*9F]R96%C
M:"!M>2`D9&ER("A`:6YC*2!["FEF("@D;F%M92`]("1005(Z.DAE879Y.CI&
M=6QL0V%C:&5[)%]]*2!["B1F:6QE(#T@)%\["FQA<W0["GT*96QS:68@*"]>
M*%Q1)&1I<EQ%7"\H+BI;7D-C72DI7%HO:2D@>PHH)&9I;&4L("1N86UE*2`]
M("@D,2P@)#(I.PIL87-T.PI]"F5L<VEF("AM(5XO;&]A9&5R+UM>+UTK+R@N
M*EM>0V-=*5Q:(2D@>PII9B`H;7D@)')E9B`]("1005(Z.DAE879Y.CI-;V1U
M;&5#86-H97LD,7TI('L**"1F:6QE+"`D;F%M92D@/2`H)')E9BP@)#$I.PIL
M87-T.PI]"F5L<VEF("@M9B`B)&1I<B\D,2(I('L**"1F:6QE+"`D;F%M92D@
M/2`H(B1D:7(O)#$B+"`D,2D["FQA<W0["GT*?0I]"FYE>'0@=6YL97-S(&1E
M9FEN960@)&YA;64@86YD(&YO="`D=W)I='1E;GLD;F%M97TK*SL*;F5X="!I
M9B`A<F5F*"1F:6QE*2!A;F0@)&9I;&4@/7X@+UPN7%$D;&EB7V5X=%Q%)"\[
M"F]U=',H(&IO:6X@(B(L"G%Q*%!A8VMI;F<@(BDL(')E9B`D9FEL92`_("1F
M:6QE+3Y[;F%M97T@.B`D9FEL92P*<7$H(BXN+BD**3L*;7D@)&-O;G1E;G0[
M"FEF("AR968H)&9I;&4I*2!["B1C;VYT96YT(#T@)&9I;&4M/GMB=69].PI]
M"F5L<V4@>PIO<&5N($9)3$4L("<\)RP@)&9I;&4@;W(@9&EE(")#86XG="!O
M<&5N("1F:6QE.B`D(2(["F)I;FUO9&4H1DE,12D["B1C;VYT96YT(#T@/$9)
M3$4^.PIC;&]S92!&24Q%.PI005(Z.D9I;'1E<CHZ4&]D4W1R:7`M/FYE=RT^
M87!P;'DH7"1C;VYT96YT+"`D9FEL92D*:68@(21%3E9[4$%27U9%4D)!5$E-
M?2!A;F0@)&YA;64@/7X@+UPN*#\Z<&U\:7A\86PI)"]I.PI005(Z.D9I;'1E
M<CHZ4&%T8VA#;VYT96YT+3YN97<M/F%P<&QY*%PD8V]N=&5N="P@)&9I;&4L
M("1N86UE*3L*?0IO=71S*'%Q*%=R:71T96X@87,@(B1N86UE(BDI.PHD9F@M
M/G!R:6YT*")&24Q%(BD["B1F:"T^<')I;G0H<&%C:R@G3B<L(&QE;F=T:"@D
M;F%M92D@*R`Y*2D["B1F:"T^<')I;G0H<W!R:6YT9B@*(B4P.'@O)7,B+"!!
M<F-H:79E.CI::7`Z.F-O;7!U=&5#4D,S,B@D8V]N=&5N="DL("1N86UE"BDI
M.PHD9F@M/G!R:6YT*'!A8VLH)TXG+"!L96YG=&@H)&-O;G1E;G0I*2D["B1F
M:"T^<')I;G0H)&-O;G1E;G0I.PI]"GT*)'II<"T^=W)I=&54;T9I;&5(86YD
M;&4H)&9H*2!I9B`D>FEP.PHD8V%C:&5?;F%M92`]('-U8G-T<B`D8V%C:&5?
M;F%M92P@,"P@-#`["FEF("@A)&-A8VAE7VYA;64@86YD(&UY("1M=&EM92`]
M("AS=&%T*"1O=70I*5LY72D@>PIM>2`D8W1X(#T@1&EG97-T.CI32$$M/FYE
M=R@Q*3L*;W!E;BAM>2`D9F@L("(\(BP@)&]U="D["F)I;FUO9&4H)&9H*3L*
M)&-T>"T^861D9FEL92@D9F@I.PIC;&]S92@D9F@I.PHD8V%C:&5?;F%M92`]
M("1C='@M/FAE>&1I9V5S=#L*?0HD8V%C:&5?;F%M92`N/2`B7#`B('@@*#0Q
M("T@;&5N9W1H("1C86-H95]N86UE*3L*)&-A8VAE7VYA;64@+CT@(D-!0TA%
M(CL*)&9H+3YP<FEN="@D8V%C:&5?;F%M92D["B1F:"T^<')I;G0H<&%C:R@G
M3B<L("1F:"T^=&5L;"`M(&QE;F=T:"@D;&]A9&5R*2DI.PHD9F@M/G!R:6YT
M*"1005)?34%'24,I.PHD9F@M/F-L;W-E.PIC:&UO9"`P-S4U+"`D;W5T.PIE
M>&ET.PI]"GL*;&%S="!U;FQE<W,@9&5F:6YE9"`D<W1A<G1?<&]S.PI?9FEX
M7W!R;V=N86UE*"D["G)E<75I<F4@4$%2.PI005(Z.DAE879Y.CI?:6YI=%]D
M>6YA;&]A9&5R*"D["GL*<F5Q=6ER92!&:6QE.CI&:6YD.PIR97%U:7)E($%R
M8VAI=F4Z.EII<#L*?0IM>2`D9F@@/2!)3SHZ1FEL92T^;F5W.R`@("`@("`@
M("`@("`@("`@("`@("`@("`@("`@(R!!<F-H:79E.CI::7`@;W!E<F%T97,@
M;VX@86X@24\Z.DAA;F1L90HD9F@M/F9D;W!E;BAF:6QE;F\H7T9(*2P@)W(G
M*2!O<B!D:64@(B0A.B`D0"(["D%R8VAI=F4Z.EII<#HZ<V5T0VAU;FM3:7IE
M*"US(%]&2"D["FUY("1Z:7`@/2!!<F-H:79E.CI::7`M/FYE=SL*)'II<"T^
M<F5A9$9R;VU&:6QE2&%N9&QE*"1F:"P@)'!R;V=N86UE*2`]/2!!<F-H:79E
M.CI::7`Z.D%:7T]+*"D@;W(@9&EE("(D(3H@)$`B.PI!<F-H:79E.CI::7`Z
M.G-E=$-H=6YK4VEZ92@V-"`J(#$P,C0I.PIP=7-H($!005(Z.DQI8D-A8VAE
M+"`D>FEP.PHD4$%2.CI,:6)#86-H97LD<')O9VYA;65](#T@)'II<#L*)'%U
M:65T(#T@(21%3E9[4$%27T1%0E5'?3L*;W5T<RAQ<2A<)$5.5GM005)?5$5-
M4'T@/2`B)$5.5GM005)?5$5-4'TB*2D["FEF("AD969I;F5D("1%3E9[4$%2
M7U1%35!]*2![(",@<VAO=6QD(&)E('-E="!A="!T:&ES('!O:6YT(0IF;W)E
M86-H(&UY("1M96UB97(@*"`D>FEP+3YM96UB97)S("D@>PIN97AT(&EF("1M
M96UB97(M/FES1&ER96-T;W)Y.PIM>2`D;65M8F5R7VYA;64@/2`D;65M8F5R
M+3YF:6QE3F%M93L*;F5X="!U;FQE<W,@)&UE;6)E<E]N86UE(#U^(&U["EX*
M+S]S:&QI8B\**#\Z)$-O;F9I9SHZ0V]N9FEG>W9E<G-I;VY]+RD_"B@_.B1#
M;VYF:6<Z.D-O;F9I9WMA<F-H;F%M97TO*3\**%M>+UTK*0HD"GUX.PIM>2`D
M97AT<F%C=%]N86UE(#T@)#$["FUY("1D97-T7VYA;64@/2!&:6QE.CI3<&5C
M+3YC871F:6QE*"1%3E9[4$%27U1%35!]+"`D97AT<F%C=%]N86UE*3L*:68@
M*"UF("1D97-T7VYA;64@)B8@+7,@7R`]/2`D;65M8F5R+3YU;F-O;7!R97-S
M9613:7IE*"DI('L*;W5T<RAQ<2A3:VEP<&EN9R`B)&UE;6)E<E]N86UE(B!S
M:6YC92!I="!A;')E861Y(&5X:7-T<R!A="`B)&1E<W1?;F%M92(I*3L*?2!E
M;'-E('L*;W5T<RAQ<2A%>'1R86-T:6YG("(D;65M8F5R7VYA;64B('1O("(D
M9&5S=%]N86UE(BDI.PHD;65M8F5R+3YE>'1R86-T5&]&:6QE3F%M960H)&1E
M<W1?;F%M92D["F-H;6]D*#`U-34L("1D97-T7VYA;64I(&EF("1>3R!E<2`B
M:'!U>"(["GT*?0I]"GT*=6YL97-S("@D4$%2.CI,:6)#86-H97LD<')O9VYA
M;65]*2!["F1I92`\/"`B+B(@=6YL97-S($!!4D=6.PI5<V%G93H@)#`@6R`M
M06QI8BYP87(@72!;("U)9&ER(%T@6R`M36UO9'5L92!=(%L@<W)C+G!A<B!=
M(%L@<')O9W)A;2YP;"!="B0P(%L@+4)\+6(@72!;+4]O=71F:6QE72!S<F,N
M<&%R"BX*)$5.5GM005)?4%)/1TY!345](#T@)'!R;V=N86UE(#T@)#`@/2!S
M:&EF="A`05)'5BD["GT*<W5B($-R96%T95!A=&@@>PIM>2`H)&YA;64I(#T@
M0%\["G)E<75I<F4@1FEL93HZ0F%S96YA;64["FUY("@D8F%S96YA;64L("1P
M871H+"`D97AT*2`]($9I;&4Z.D)A<V5N86UE.CIF:6QE<&%R<V4H)&YA;64L
M("@G7"XN*B<I*3L*<F5Q=6ER92!&:6QE.CI0871H.PI&:6QE.CI0871H.CIM
M:W!A=&@H)'!A=&@I('5N;&5S<R@M92`D<&%T:"D[(",@;6MP871H(&1I97,@
M=VET:"!E<G)O<@I]"G-U8B!R97%U:7)E7VUO9'5L97,@>PIR97%U:7)E(&QI
M8CL*<F5Q=6ER92!$>6YA3&]A9&5R.PIR97%U:7)E(&EN=&5G97(["G)E<75I
M<F4@<W1R:6-T.PIR97%U:7)E('=A<FYI;F=S.PIR97%U:7)E('9A<G,["G)E
M<75I<F4@0V%R<#L*<F5Q=6ER92!#87)P.CI(96%V>3L*<F5Q=6ER92!%<G)N
M;SL*<F5Q=6ER92!%>'!O<G1E<CHZ2&5A=GD["G)E<75I<F4@17AP;W)T97([
M"G)E<75I<F4@1F-N=&P["G)E<75I<F4@1FEL93HZ5&5M<#L*<F5Q=6ER92!&
M:6QE.CI3<&5C.PIR97%U:7)E(%A33&]A9&5R.PIR97%U:7)E($-O;F9I9SL*
M<F5Q=6ER92!)3SHZ2&%N9&QE.PIR97%U:7)E($E/.CI&:6QE.PIR97%U:7)E
M($-O;7!R97-S.CI:;&EB.PIR97%U:7)E($%R8VAI=F4Z.EII<#L*<F5Q=6ER
M92!$:6=E<W0Z.E-(03L*<F5Q=6ER92!005(["G)E<75I<F4@4$%2.CI(96%V
M>3L*<F5Q=6ER92!005(Z.D1I<W0["G)E<75I<F4@4$%2.CI&:6QT97(Z.E!O
M9%-T<FEP.PIR97%U:7)E(%!!4CHZ1FEL=&5R.CI0871C:$-O;G1E;G0["G)E
M<75I<F4@871T<FEB=71E<SL*979A;"![(')E<75I<F4@0W=D('T["F5V86P@
M>R!R97%U:7)E(%=I;C,R('T["F5V86P@>R!R97%U:7)E(%-C86QA<CHZ571I
M;"!].PIE=F%L('L@<F5Q=6ER92!!<F-H:79E.CI5;GII<#HZ0G5R<W0@?3L*
M979A;"![(')E<75I<F4@5&EE.CI(87-H.CI.86UE9$-A<'1U<F4@?3L*979A
M;"![(')E<75I<F4@4&5R;$E/.R!R97%U:7)E(%!E<FQ)3SHZ<V-A;&%R('T[
M"F5V86P@>R!R97%U:7)E('5T9C@@?3L*?0IS=6(@7W-E=%]P87)?=&5M<"![
M"FEF("AD969I;F5D("1%3E9[4$%27U1%35!](&%N9"`D14Y6>U!!4E]414U0
M?2`]?B`O*"XK*2\I('L*)'!A<E]T96UP(#T@)#$["G)E='5R;CL*?0IF;W)E
M86-H(&UY("1P871H("@**&UA<"`D14Y6>R1??2P@<7<H(%!!4E]435!$25(@
M5$U01$E2(%1%35!$25(@5$5-4"!435`@*2DL"G%W*"!#.EQ<5$5-4"`O=&UP
M("X@*0HI('L*;F5X="!U;FQE<W,@9&5F:6YE9"`D<&%T:"!A;F0@+60@)'!A
M=&@@86YD("UW("1P871H.PIM>2`D=7-E<FYA;64["FUY("1P=W5I9#L*979A
M;"![*"1P=W5I9"D@/2!G971P=W5I9"@D/BD@:68@9&5F:6YE9"`D/CM].PII
M9B`H(&1E9FEN960H)E=I;C,R.CI,;V=I;DYA;64I("D@>PHD=7-E<FYA;64@
M/2`F5VEN,S(Z.DQO9VEN3F%M93L*?0IE;'-I9B`H9&5F:6YE9"`D<'=U:60I
M('L*)'5S97)N86UE(#T@)'!W=6ED.PI]"F5L<V4@>PHD=7-E<FYA;64@/2`D
M14Y6>U5315).04U%?2!\?"`D14Y6>U5315)]('Q\("=365-414TG.PI]"B1U
M<V5R;F%M92`]?B!S+UQ7+U\O9SL*;7D@)'-T;7!D:7(@/2`B)'!A=&@D0V]N
M9FEG>U]D96QI;7UP87(M(BYU;G!A8VLH(D@J(BP@)'5S97)N86UE*3L*;6MD
M:7(@)'-T;7!D:7(L(#`W-34["FEF("@A)$5.5GM005)?0TQ%04Y](&%N9"!M
M>2`D;71I;64@/2`H<W1A="@D<')O9VYA;64I*5LY72D@>PIO<&5N("AM>2`D
M9F@L("(\(BX@)'!R;V=N86UE*3L*<V5E:R`D9F@L("TQ."P@,CL*<WES<F5A
M9"`D9F@L(&UY("1B=68L(#8["FEF("@D8G5F(&5Q(")<,$-!0TA%(BD@>PIS
M965K("1F:"P@+34X+"`R.PIS>7-R96%D("1F:"P@)&)U9BP@-#$["B1B=68@
M/7X@<R]<,"\O9SL*)'-T;7!D:7(@+CT@(B1#;VYF:6=[7V1E;&EM?6-A8VAE
M+2(@+B`D8G5F.PI]"F5L<V4@>PIM>2`D9&EG97-T(#T@979A;`I["G)E<75I
M<F4@1&EG97-T.CI32$$["FUY("1C='@@/2!$:6=E<W0Z.E-(02T^;F5W*#$I
M.PIO<&5N*&UY("1F:"P@(CPB+"`D<')O9VYA;64I.PIB:6YM;V1E*"1F:"D[
M"B1C='@M/F%D9&9I;&4H)&9H*3L*8VQO<V4H)&9H*3L*)&-T>"T^:&5X9&EG
M97-T.PI]("\O("1M=&EM93L*)'-T;7!D:7(@+CT@(B1#;VYF:6=[7V1E;&EM
M?6-A8VAE+21D:6=E<W0B.PI]"F-L;W-E*"1F:"D["GT*96QS92!["B1%3E9[
M4$%27T-,14%.?2`](#$["B1S=&UP9&ER("X]("(D0V]N9FEG>U]D96QI;7UT
M96UP+20D(CL*?0HD14Y6>U!!4E]414U0?2`]("1S=&UP9&ER.PIM:V1I<B`D
M<W1M<&1I<BP@,#<U-3L*;&%S=#L*?0HD<&%R7W1E;7`@/2`D,2!I9B`D14Y6
M>U!!4E]414U0?2!A;F0@)$5.5GM005)?5$5-4'T@/7X@+R@N*RDO.PI]"G-U
M8B!?=&5M<&9I;&4@>PIM>2`H)&YA;64L("1C;VYT96YT<RP@)&UO9&4I(#T@
M0%\["FUY("1F=6QL;F%M92`]("(D<&%R7W1E;7`O)&YA;64B.PIU;FQE<W,@
M*"UE("1F=6QL;F%M92D@>PIM>2`D=&5M<&YA;64@/2`B)&9U;&QN86UE+B0D
M(CL*;W!E;B!M>2`D9F@L("<^)RP@)'1E;7!N86UE(&]R(&1I92`B8V%N)W0@
M=W)I=&4@)'1E;7!N86UE.B`D(2(["F)I;FUO9&4@)&9H.PIP<FEN="`D9F@@
M)&-O;G1E;G1S.PIC;&]S92`D9F@["F-H;6]D("1M;V1E+"`D=&5M<&YA;64@
M:68@9&5F:6YE9"`D;6]D93L*<F5N86UE*"1T96UP;F%M92P@)&9U;&QN86UE
M*2!O<B!U;FQI;FLH)'1E;7!N86UE*3L*?0IR971U<FX@)&9U;&QN86UE.PI]
M"G-U8B!?<V5T7W!R;V=N86UE('L*:68@*&1E9FEN960@)$5.5GM005)?4%)/
M1TY!345](&%N9"`D14Y6>U!!4E]04D]'3D%-17T@/7X@+R@N*RDO*2!["B1P
M<F]G;F%M92`]("0Q.PI]"B1P<F]G;F%M92!\?#T@)#`["FEF("@D14Y6>U!!
M4E]414U0?2!A;F0@:6YD97@H)'!R;V=N86UE+"`D14Y6>U!!4E]414U0?2D@
M/CT@,"D@>PHD<')O9VYA;64@/2!S=6)S='(H)'!R;V=N86UE+"!R:6YD97@H
M)'!R;V=N86UE+"`D0V]N9FEG>U]D96QI;7TI("L@,2D["GT*:68@*"$D14Y6
M>U!!4E]04D]'3D%-17T@;W(@:6YD97@H)'!R;V=N86UE+"`D0V]N9FEG>U]D
M96QI;7TI(#X](#`I('L*:68@*&]P96X@;7D@)&9H+"`G/"<L("1P<F]G;F%M
M92D@>PIR971U<FX@:68@+7,@)&9H.PI]"FEF("@M<R`B)'!R;V=N86UE)$-O
M;F9I9WM?97AE?2(I('L*)'!R;V=N86UE("X]("1#;VYF:6=[7V5X97T["G)E
M='5R;CL*?0I]"F9O<F5A8V@@;7D@)&1I<B`H<W!L:70@+UQ1)$-O;F9I9WMP
M871H7W-E<'U<12\L("1%3E9[4$%42'TI('L*;F5X="!I9B!E>&ES=',@)$5.
M5GM005)?5$5-4'T@86YD("1D:7(@97$@)$5.5GM005)?5$5-4'T["B1D:7(@
M/7X@<R]<421#;VYF:6=[7V1E;&EM?5Q%)"\O.PHH*"1P<F]G;F%M92`]("(D
M9&ER)$-O;F9I9WM?9&5L:6U])'!R;V=N86UE)$-O;F9I9WM?97AE?2(I+"!L
M87-T*0II9B`M<R`B)&1I<B1#;VYF:6=[7V1E;&EM?21P<F]G;F%M921#;VYF
M:6=[7V5X97TB.PHH*"1P<F]G;F%M92`]("(D9&ER)$-O;F9I9WM?9&5L:6U]
M)'!R;V=N86UE(BDL(&QA<W0I"FEF("US("(D9&ER)$-O;F9I9WM?9&5L:6U]
M)'!R;V=N86UE(CL*?0I]"G-U8B!?9FEX7W!R;V=N86UE('L*)#`@/2`D<')O
M9VYA;64@?'P]("1%3E9[4$%27U!23T=.04U%?3L*:68@*&EN9&5X*"1P<F]G
M;F%M92P@)$-O;F9I9WM?9&5L:6U]*2`\(#`I('L*)'!R;V=N86UE(#T@(BXD
M0V]N9FEG>U]D96QI;7TD<')O9VYA;64B.PI]"FUY("1P=V0@/2`H9&5F:6YE
M9"`F0W=D.CIG971C=V0I(#\@0W=D.CIG971C=V0H*0HZ("@H9&5F:6YE9"`F
M5VEN,S(Z.D=E=$-W9"D@/R!7:6XS,CHZ1V5T0W=D*"D@.B!@<'=D8"D["F-H
M;VUP*"1P=V0I.PHD<')O9VYA;64@/7X@<R]>*#\]7"Y<+C]<421#;VYF:6=[
M7V1E;&EM?5Q%*2\D<'=D)$-O;F9I9WM?9&5L:6U]+SL*)$5.5GM005)?4%)/
M1TY!345](#T@)'!R;V=N86UE.PI]"G-U8B!?<&%R7VEN:71?96YV('L*:68@
M*"`D14Y6>U!!4E])3DE424%,25I%1'TK*R`]/2`Q("D@>PIR971U<FX["GT@
M96QS92!["B1%3E9[4$%27TE.251)04Q)6D5$?2`](#(["GT*9F]R("AQ=R@@
M4U!!5TY%1"!414U0($-,14%.($1%0E5'($-!0TA%(%!23T=.04U%("D@*2![
M"F1E;&5T92`D14Y6>R=005)?)RXD7WT["GT*9F]R("AQ=R\@5$U01$E2(%1%
M35`@0TQ%04X@1$5"54<@+RD@>PHD14Y6>R=005)?)RXD7WT@/2`D14Y6>R=0
M05)?1TQ/0D%,7R<N)%]](&EF(&5X:7-T<R`D14Y6>R=005)?1TQ/0D%,7R<N
M)%]].PI]"FUY("1P87)?8VQE86X@/2`B7U]%3E9?4$%27T-,14%.7U\@("`@
M("`@("`@("`@("`B.PII9B`H)$5.5GM005)?5$5-4'TI('L*9&5L971E("1%
M3E9[4$%27T-,14%.?3L*?0IE;'-I9B`H(65X:7-T<R`D14Y6>U!!4E]'3$]"
M04Q?0TQ%04Y]*2!["FUY("1V86QU92`]('-U8G-T<B@D<&%R7V-L96%N+"`Q
M,B`K(&QE;F=T:"@B0TQ%04XB*2D["B1%3E9[4$%27T-,14%.?2`]("0Q(&EF
M("1V86QU92`]?B`O7E!!4E]#3$5!3CTH7%,K*2\["GT*?0IS=6(@;W5T<R![
M"G)E='5R;B!I9B`D<75I970["FEF("@D;&]G9F@I('L*<')I;G0@)&QO9V9H
M(")`7UQN(CL*?0IE;'-E('L*<')I;G0@(D!?7&XB.PI]"GT*<W5B(&EN:71?
M:6YC('L*<F5Q=6ER92!#;VYF:6<["G!U<V@@0$E.0RP@9W)E<"!D969I;F5D
M+"!M87`@)$-O;F9I9SHZ0V]N9FEG>R1??2P@<7<H"F%R8VAL:6)E>'`@<')I
M=FQI8F5X<"!S:71E87)C:&5X<"!S:71E;&EB97AP"G9E;F1O<F%R8VAE>'`@
M=F5N9&]R;&EB97AP"BD["GT*<&%C:V%G92!M86EN.PIR97%U:7)E(%!!4CL*
M=6YS:&EF="!`24Y#+"!<)E!!4CHZ9FEN9%]P87(["E!!4BT^:6UP;W)T*$!P
M87)?87)G<RD["F1I92!Q<2AP87(N<&PZ($-A;B=T(&]P96X@<&5R;"!S8W)I
M<'0@(B1P<F]G;F%M92(Z($YO('-U8V@@9FEL92!O<B!D:7)E8W1O<GE<;BD*
M=6YL97-S("UE("1P<F]G;F%M93L*9&\@)'!R;V=N86UE.PI#3U)%.CIE>&ET
M*"0Q*2!I9B`H)$`@/7XO7E]42U]%6$E47UPH*%QD*RE<*2\I.PID:64@)$`@
M:68@)$`["GT["B0Z.E]?15)23U(@/2`D0"!I9B`D0#L*?0I#3U)%.CIE>&ET
M*"0Q*2!I9B`H)#HZ7U]%4E)/4B`]?B]>7U1+7T58251?7"@H7&0K*5PI+RD[
M"F1I92`D.CI?7T524D]2(&EF("0Z.E]?15)23U(["C$["E]?14Y$7U\*``$;
M`SO8````&@````"'__^0!```)(S__P@!``#TC/__0`$``%2-__]@`0``^(W_
M_X@!```8D/__Q`$``)R1__\``@``1)+__R@"``"HDO__2`(``""3__]L`@``
M^)/__Y@"```0E/__K`(``""6___\`@``6);__Q`#``"XE___.`,``'R9__]H
M`P``")K__X@#``!4FO__J`,``!B;___<`P``.*+__R`$```@IO__7`0``+BF
M__^X!```Y+S___P$``!XO?__'`4``+B^__]4!0``8,'___`````0````````
M``%Z4@`$>$$!&PP!`!0````8````:,#__RP!````00E!`$<&030````P````
M%(O__]``````0PE!`$&:!IL%G`2=`YX"GP$107Y"#E!*"@X`0M_>W=S;V@9!
M"P``'````&@```"LB___8`````!%#G`107Y-#@!"!D$````D````B````.R+
M__^D`````$4)00">`I\!0PZ``1%!?ET.`$'?W@9!.````+````!HC/__(`(`
M``!#"4$`09D'F@:;!9P$G0.>`I\!$4%^00ZP`0)_#@!!W][=W-O:V09!````
M.````.P```!,CO__A`$```!#"4$`09@(F0>:!IL%G`2=`YX"GP$107Y!#L`"
M`E@.`$'?WMW<V]K9V`9!)````"@!``"4C___J`````!$"4$`GP%##M`!$4%^
M7PX`0=\&00```!P```!0`0``%)#__V0`````1PX@$4%^3`X`0@9!````(```
M`'`!``!8D/__>`````!$"4$`GP%$#C`107Y2#@!!WP9!*````)0!``"LD/__
MV`````!#"4$`09T#G@*?`1%!?D$.H$%M#@!!W][=!D$0````P`$``%B1__\8
M`````````$P```#4`0``7)'__Q`"````10E!`!%(?T&4#)4+E@J7"9@(F0>:
M!IL%G`2=`YX"GP$107Y!#N`B`G<.`$/?WMW<V]K9V-?6U=0&009(````$```
M`"0"```<D___.``````````D````.`(``$"3__]@`0```$0)00"?`4,.,!%!
M?@)-#@!!WP9!````+````&`"``!XE/__Q`$```!'"4$`09P$G0.>`I\!$4%^
M00ZP`0)D#@!!W][=W`9!'````)`"```,EO__C`````!+#F`107Y,#@!$!D$`
M```<````L`(``'B6__],`````$4.(!%!?D@.`$(&00```#````#0`@``I);_
M_\0`````0PE!`$&<!)T#G@*?`1%!?D$.@`%."@X`0=_>W=P&00L```!`````
M!`,``#27__\@!P```$4)00!!EPF8")D'F@:;!9P$G0.>`I\!$4%^1P[P@P(#
MMP$.`$'?WMW<V]K9V-<&00```#@```!(`P``$)[__^@#````0PE!`$&8")D'
MF@:;!9P$G0.>`I\!$4%^00Z@`0+Q#@!!W][=W-O:V=@&03````"$`P``O*'_
M_Y@`````10E!`)X"GP%##G`107Y3"@X`109!W]Y!"T$.`$'?W@9!```D````
MN`,``&B"__]T`@```$<.D`$107Z>`I\!`HD*#@!"W]X&00L`0````.`#``#X
MH?__+!8```!$"4$`098*EPF8")D'F@:;!9P$G0.>`I\!$4%^00Z`!@.!!0X`
M0=_>W=S;VMG8U]8&00`<````)`0``."W__^4`````$8.(!%!?D0.`%<&00``
M`#0```!$!```5+C__T`!````1`E!`$&:!IL%G`2=`YX"GP$107Y!#E!R"@X`
M0=_>W=S;V@9!"P``,````'P$``!<N?__I`$```!%"4$`09L%G`2=`YX"GP$1
M07Y!#E`"6@H.`$'?WMW<VP9!"P``````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````__________\`
M`````````/__________```````````!``````````$``````````0``````
M``"^`@````````\`````````1`0````````,`````````+@8````````#0``
M```````L7````````/7^_V\`````(`(````````%`````````'`,````````
M!@````````#X`@````````H`````````8@0````````+`````````!@`````
M````%0````````````````````,`````````"/T!```````"`````````+@%
M````````%``````````'`````````!<``````````!,```````````!P````
M`!A;`````````P``<`````````````````<`````````V!`````````(````
M`````"@"````````"0`````````8`````````!@```````````````````#[
M__]O``````$```@`````^?__;P`````+````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M`````````````````````````````````````````'\"````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M`````````````````````````@``````_____P`````Z7P```````(5<````
M``````````````!F70```````%]=````````+E\```````!\70```````#9?
M```````````````````@7P```````"5?```````````````````_7P``````
M`$=#0SH@*$%L<&EN92`X+C,N,"D@."XS+C```"YS:'-T<G1A8@`N:6YT97)P
M`"YG;G4N:&%S:``N9'EN<WEM`"YD>6YS='(`+G)E;&$N9'EN`"YR96QA+G!L
M=``N:6YI=``N=&5X=``N9FEN:0`N<F]D871A`"YE:%]F<F%M95]H9'(`+F5H
M7V9R86UE`"YC=&]R<P`N9'1O<G,`+F1Y;F%M:6,`+F=O=``N9&%T80`N8G-S
M`"YC;VUM96YT````````````````````````````````````````````````
M```````````````````````````````````````````+`````0````(`````
M``````(``````````@```````!X````````````````````!````````````
M````````$P```/;__V\"`````````"`"````````(`(```````#8````````
M``,`````````"````````````````````!T````+`````@````````#X`@``
M`````/@"````````>`D````````$`````P````@`````````&``````````E
M`````P````(`````````<`P```````!P#````````&($````````````````
M```!````````````````````+0````0````"`````````-@0````````V!``
M```````H`@````````,`````````"``````````8`````````#<````$````
M0@``````````$P`````````3````````N`4````````#````$`````@`````
M````&`````````!!`````0````8`````````N!@```````"X&````````#0`
M```````````````````$````````````````````1P````$````&````````
M```9`````````!D````````L0P``````````````````(```````````````
M`````$T````!````!@`````````L7````````"Q<````````+```````````
M``````````0```````````````````!3`````0````(`````````6%P`````
M``!87````````$@]```````````````````(````````````````````6P``
M``$````"`````````*"9````````H)D```````#<````````````````````
M!````````````````````&D````!`````@````````!\F@```````'R:````
M````L`0```````````````````0```````````````````!S`````0````,`
M````````*/L!```````H^P```````!`````````````````````(````````
M````````````>@````$````#`````````#C[`0``````./L````````0````
M````````````````"````````````````````($````&`````P````````!(
M^P$``````$C[````````P`$````````$``````````@`````````$```````
M```\````"`````,`````````"/T!```````(_0```````/@!````````````
M```````(``````````@`````````B@````$````#``````````#_`0``````
M`/\```````!H``````````````````````$````````(`````````(\````!
M`````P````````````(``````````0``````>`````````````````````@`
M``````````````````"5````"`````,`````````>``"``````!X``$`````
M`&@0```````````````````(````````````````````F@````$````P````
M````````````````>``!```````:`````````````````````0`````````!
M``````````$````#`````````````````````````)(``0``````HP``````
:``````````````$`````````````````````
